@@ -1,8 +1,8 @@
 // Test copyDatabase command with various combinations of authed/unauthed and single node/replica
 // set source and dest.
 
-TestData.authMechanism = "MONGODB-CR"; // SERVER-11428
-DB.prototype._defaultAuthenticationMechanism = "MONGODB-CR"; // SERVER-11428
+TestData.authMechanism = "SCRAM-SHA-1"; // SERVER-11428
+DB.prototype._defaultAuthenticationMechanism = "SCRAM-SHA-1"; // SERVER-11428
 
 var baseName = "jstests_clone_copyauth";
 
@@ -34,7 +34,7 @@ function ClusterSpawnHelper(clusterType, startWithAuth) {
             mongos : 1,
             shards : 1,
             config : 1
-        }
+        };
         if (startWithAuth) {
             shardingTestConfig.auth = "";
             shardingTestConfig.keyFile = "jstests/libs/key1";
@@ -52,8 +52,15 @@ function ClusterSpawnHelper(clusterType, startWithAuth) {
         var replSetTest = new ReplSetTest(replSetTestConfig);
         replSetTest.startSet();
         replSetTest.initiate();
-        replSetTest.awaitReplication();
-        this.conn = replSetTest.getMaster();
+        if (startWithAuth) {
+            authutil.asCluster(replSetTest.nodes,
+                               replSetTestConfig.nodeOptions.keyFile,
+                               function() { replSetTest.awaitReplication(); });
+        }
+        else {
+            replSetTest.awaitReplication();
+        }
+        this.conn = replSetTest.getPrimary();
         this.connString = replSetTest.getURL();
     }
     else {
@@ -75,7 +82,7 @@ function ClusterSpawnHelper(clusterType, startWithAuth) {
         else {
             MongoRunner.stopMongod(this.conn.port);
         }
-    }
+    };
 }
 
 /*
@@ -103,7 +110,7 @@ function copydbBetweenClustersTest(configObj) {
         'isSourceUsingAuth',
         'targetClusterType',
         'isTargetUsingAuth'
-    ]
+    ];
 
     var i;
     for (i = 0; i < requiredKeys.length; i++) {
@@ -116,16 +123,16 @@ function copydbBetweenClustersTest(configObj) {
     // 1. Get a connection to the source database, insert data and setup auth if applicable
     source = new ClusterSpawnHelper(configObj.sourceClusterType, configObj.isSourceUsingAuth);
 
-    source.conn.getDB(baseName)[baseName].save({i:1});
-    assert.eq(1, source.conn.getDB(baseName)[baseName].count());
-    assert.eq(1, source.conn.getDB(baseName)[baseName].findOne().i);
-
     if (configObj.isSourceUsingAuth) {
         // Create a super user so we can create a regular user and not be locked out afterwards
         source.conn.getDB("admin").createUser({ user: "sourceSuperUser", pwd: "sourceSuperUser",
                                                 roles: [ "root" ] });
         source.conn.getDB("admin").auth("sourceSuperUser", "sourceSuperUser");
 
+        source.conn.getDB(baseName)[baseName].save({i:1});
+        assert.eq(1, source.conn.getDB(baseName)[baseName].count());
+        assert.eq(1, source.conn.getDB(baseName)[baseName].findOne().i);
+
         // Insert a document and create a regular user that we will use for the target
         // authenticating with the source
         source.conn.getDB(baseName).createUser({ user: "foo", pwd: "bar",
@@ -133,6 +140,10 @@ function copydbBetweenClustersTest(configObj) {
 
         source.conn.getDB("admin").logout();
         assert.throws(function() { source.conn.getDB(baseName)[baseName].findOne(); });
+    } else {
+        source.conn.getDB(baseName)[baseName].save({i:1});
+        assert.eq(1, source.conn.getDB(baseName)[baseName].count());
+        assert.eq(1, source.conn.getDB(baseName)[baseName].findOne().i);
     }
 
 
@@ -174,10 +185,13 @@ function copydbBetweenClustersTest(configObj) {
     target.stop();
 }
 
-var sourceClusterTypeValues = [ "single", "repl", "sharded" ]
-var isSourceUsingAuthValues = [ true, false ]
-var targetClusterTypeValues = [ "single", "repl", "sharded" ]
-var isTargetUsingAuthValues = [ true, false ]
+(function() {
+"use strict";
+
+var sourceClusterTypeValues = [ "single", "repl", "sharded" ];
+var isSourceUsingAuthValues = [ true, false ];
+var targetClusterTypeValues = [ "single", "repl", "sharded" ];
+var isTargetUsingAuthValues = [ true, false ];
 for (var i = 0; i < sourceClusterTypeValues.length; i++) {
     for (var j = 0; j < isSourceUsingAuthValues.length; j++) {
         for (var k = 0; k < targetClusterTypeValues.length; k++) {
@@ -197,12 +211,19 @@ for (var i = 0; i < sourceClusterTypeValues.length; i++) {
                     // SERVER-6427
                     continue;
                 }
+                if (sourceClusterTypeValues[i] === "repl" &&
+                    isSourceUsingAuthValues[j] === false &&
+                    targetClusterTypeValues[k] === "sharded" &&
+                    isTargetUsingAuthValues[l] == true) {
+                    // SERVER-18103
+                    continue;
+                }
                 var testCase = {
                     'sourceClusterType' : sourceClusterTypeValues[i],
                     'isSourceUsingAuth' : isSourceUsingAuthValues[j],
                     'targetClusterType' : targetClusterTypeValues[k],
                     'isTargetUsingAuth' : isTargetUsingAuthValues[l]
-                }
+                };
                 print("Running copydb with auth test:");
                 printjson(testCase);
                 copydbBetweenClustersTest(testCase);
@@ -210,5 +231,5 @@ for (var i = 0; i < sourceClusterTypeValues.length; i++) {
         }
     }
 }
-
+}());
 print(baseName + " success!");
