@@ -1,17 +1,14 @@
 // test renameCollection with auth
 
-port = allocatePorts( 1 )[ 0 ];
+var m = MongoRunner.runMongod({auth: ""});
 
-baseName = "jstests_rename_auth";
-m = startMongod( "--auth", "--port", port, "--dbpath", MongoRunner.dataPath + baseName, "--nohttpinterface" );
-
-db1 = m.getDB( baseName )
-db2 = m.getDB( baseName + '_other' )
-admin = m.getDB( 'admin' )
+var db1 = m.getDB("foo");
+var db2 = m.getDB("bar");
+var admin = m.getDB( 'admin' );
 
 // Setup initial data
 admin.createUser({user:'admin', pwd: 'password', roles: jsTest.adminUserRoles});
-admin.auth('admin', 'password')
+admin.auth('admin', 'password');
 
 db1.createUser({user: "foo", pwd: "bar", roles: jsTest.basicUserRoles});
 db2.createUser({user: "bar", pwd: "foo", roles: jsTest.basicUserRoles});
@@ -26,7 +23,7 @@ admin.logout();
 assert.commandFailed( admin.runCommand({renameCollection:db1.a.getFullName(), to: db1.b.getFullName()}) );
 
 // can run same db with auth
-db1.auth('foo', 'bar')
+db1.auth('foo', 'bar');
 assert.commandWorked( admin.runCommand({renameCollection:db1.a.getFullName(), to: db1.b.getFullName()}) );
 
 // can't run diff db w/o auth
