@@ -1,5 +1,5 @@
 
-t = db.bench_test2
+t = db.bench_test2;
 t.drop();
 
 for ( i=0; i<100; i++ )
@@ -11,8 +11,7 @@ benchArgs = { ops : [ { ns : t.getFullName() ,
                         update : { $inc : { x : 1 } } } ] ,
               parallel : 2 ,
               seconds : 1 ,
-              totals : true ,
-              host : db.getMongo().host }
+              host : db.getMongo().host };
 
 if (jsTest.options().auth) {
     benchArgs['db'] = 'admin';
@@ -20,13 +19,13 @@ if (jsTest.options().auth) {
     benchArgs['password'] = jsTest.options().adminPassword;
 }
 
-res = benchRun( benchArgs )
+res = benchRun( benchArgs );
 printjson( res );
 
-sumsq = 0
-sum = 0
+sumsq = 0;
+sum = 0;
 
-min = 1000
+min = 1000;
 max = 0;
 t.find().forEach(
     function(z){
@@ -35,14 +34,14 @@ t.find().forEach(
         min = Math.min( z.x , min );
         max = Math.max( z.x , max );
     }
-)
+);
 
-avg = sum / 100
-std = Math.sqrt( sumsq / 100 )
+avg = sum / 100;
+std = Math.sqrt( sumsq / 100 );
 
-print( "Avg: " + avg )
-print( "Std: " + std )
-print( "Min: " + min )
-print( "Max: " + max )
+print( "Avg: " + avg );
+print( "Std: " + std );
+print( "Min: " + min );
+print( "Max: " + max );
 
 
