@@ -6,7 +6,7 @@ for ( i=0; i<100; i++ ){
     t.save( { x : i } );
 }
 
-q = { x : { $gt : 25 , $lte : 75 } }
+q = { x : { $gt : 25 , $lte : 75 } };
 
 assert.eq( 50 , t.find( q ).count() , "A" );
 assert.eq( 50 , t.find( q ).itcount() , "B" );
