@@ -1,7 +1,7 @@
 // Check db name duplication constraint SERVER-2111
 
-a = db.getSisterDB( "dbcasetest_dbnamea" )
-b = db.getSisterDB( "dbcasetest_dbnameA" )
+a = db.getSisterDB( "dbcasetest_dbnamea" );
+b = db.getSisterDB( "dbcasetest_dbnameA" );
 
 a.dropDatabase();
 b.dropDatabase();
@@ -10,7 +10,6 @@ assert.writeOK( a.foo.save( { x : 1 } ));
 
 res = b.foo.save( { x : 1 } );
 assert.writeError( res );
-assert.eq( 13297, res.getWriteError().code, res.toString() );
 
 assert.neq( -1, db.getMongo().getDBNames().indexOf( a.getName() ) );
 assert.eq( -1, db.getMongo().getDBNames().indexOf( b.getName() ) );
