@@ -6,19 +6,19 @@ res = coll.runCommand("drop");
 assert( !res.ok, tojson( res ) );
 
 
-assert.eq(0, db.system.indexes.find({ns : coll + ""}).count(), "A");
+assert.eq(0, coll.getIndexes().length, "A");
 coll.save({});
-assert.eq(1, db.system.indexes.find({ns : coll + ""}).count(), "B");
+assert.eq(1, coll.getIndexes().length, "B");
 coll.ensureIndex({a : 1});
-assert.eq(2, db.system.indexes.find({ns : coll + ""}).count(), "C");
+assert.eq(2, coll.getIndexes().length, "C");
 assert.commandWorked(db.runCommand({drop : coll.getName()}));
-assert.eq(0, db.system.indexes.find({ns : coll + ""}).count(), "D");
+assert.eq(0, coll.getIndexes().length, "D");
 
 coll.ensureIndex({a : 1});
-assert.eq(2, db.system.indexes.find({ns : coll + ""}).count(), "E");
+assert.eq(2, coll.getIndexes().length, "E");
 assert.commandWorked(db.runCommand({deleteIndexes : coll.getName(), index : "*"}),
                      "delete indexes A");
-assert.eq(1, db.system.indexes.find({ns : coll + ""}).count(), "G");
+assert.eq(1, coll.getIndexes().length, "G");
 
 // make sure we can still use it
 coll.save({});
