@@ -2,7 +2,7 @@
 t = db.fts_partition_no_multikey;
 t.drop();
 
-t.ensureIndex( { x : 1, y : "text" } )
+t.ensureIndex( { x : 1, y : "text" } );
 
 assert.writeOK( t.insert( { x : 5 , y : "this is fun" } ));
 
