@@ -1,5 +1,5 @@
 
-t = db.geo_sort1
+t = db.geo_sort1;
 t.drop();
 
 for ( x=0; x<10; x++ ){
@@ -8,10 +8,10 @@ for ( x=0; x<10; x++ ){
     }
 }
 
-t.ensureIndex( { loc : "2d" , foo : 1 } )
+t.ensureIndex( { loc : "2d" , foo : 1 } );
 
-q = t.find( { loc : { $near : [ 5 , 5  ] } , foo : { $gt : 20 } } )
-m = function(z){ return z.foo; }
+q = t.find( { loc : { $near : [ 5 , 5  ] } , foo : { $gt : 20 } } );
+m = function(z){ return z.foo; };
 
 a = q.clone().map( m );
 b = q.clone().sort( { foo : 1 } ).map( m );
