@@ -1,37 +1,37 @@
 // Tests geo queries w/ update & upsert
 // from SERVER-3428
 
-var coll = db.testGeoUpdate
-coll.drop()
+var coll = db.testGeoUpdate;
+coll.drop();
 
-coll.ensureIndex({ loc : "2d" })
+coll.ensureIndex({ loc : "2d" });
 
 // Test normal update
-print( "Updating..." )
+print( "Updating..." );
 
-coll.insert({ loc : [1.0, 2.0] })
+coll.insert({ loc : [1.0, 2.0] });
 
 coll.update({ loc : { $near : [1.0, 2.0] } },
-            { x : true, loc : [1.0, 2.0] })
+            { x : true, loc : [1.0, 2.0] });
 
 // Test upsert
-print( "Upserting..." )
+print( "Upserting..." );
             
 coll.update({ loc : { $within : { $center : [[10, 20], 1] } } },
             { x : true },
-            true)
+            true);
             
 coll.update({ loc : { $near : [10.0, 20.0], $maxDistance : 1 } },
             { x : true },
-            true)
+            true);
            
             
 coll.update({ loc : { $near : [100, 100], $maxDistance : 1 } }, 
             { $set : { loc : [100, 100] }, $push : { people : "chris" } },
-            true)
+            true);
             
 coll.update({ loc : { $near : [100, 100], $maxDistance : 1 } }, 
             { $set : { loc : [100, 100] }, $push : { people : "john" } },
-            true)
+            true);
 
-assert.eq( 4, coll.find().itcount() )
+assert.eq( 4, coll.find().itcount() );
