@@ -1,7 +1,7 @@
 // tests getlog as well as slow querying logging
 
 glcol = db.getLogTest2;
-glcol.drop()
+glcol.drop();
 
 contains = function(arr, func) {
     var i = arr.length;
@@ -11,7 +11,7 @@ contains = function(arr, func) {
         }
     }
     return false;
-}
+};
 
 // test doesn't work when talking to mongos
 if(db.isMaster().msg != "isdbgrid") {
@@ -30,17 +30,19 @@ if(db.isMaster().msg != "isdbgrid") {
   // ensure that slow query is logged in detail
   assert( contains(resp.log, function(v) {
    print(v);
-   return v.indexOf(" query ") != -1 && v.indexOf("query:") != -1 &&
-          v.indexOf("nscanned:") != -1 &&
-          v.indexOf("nscannedObjects:") != -1 &&
+   var opString = db.getMongo().useReadCommands() ? " find " : " query ";
+   var filterString = db.getMongo().useReadCommands() ? "filter:" : "query:";
+   return v.indexOf(opString) != -1 && v.indexOf(filterString) != -1 &&
+          v.indexOf("keysExamined:") != -1 &&
+          v.indexOf("docsExamined:") != -1 &&
           v.indexOf("SENTINEL") != -1;
   }) );
 
   // same, but for update
   assert( contains(resp.log, function(v) {
    return v.indexOf(" update ") != -1 && v.indexOf("query") != -1 &&
-          v.indexOf("nscanned:") != -1 &&
-          v.indexOf("nscannedObjects:") != -1 &&
+          v.indexOf("keysExamined:") != -1 &&
+          v.indexOf("docsExamined:") != -1 &&
           v.indexOf("SENTINEL") != -1;
   }) );
 }
