@@ -14,11 +14,11 @@ function basic1( key , lookup , shouldFail){
 
 }
 
-basic1( 6 )
-basic1( new Date() )
-basic1( "eliot" )
+basic1( 6 );
+basic1( new Date() );
+basic1( "eliot" );
 basic1( { a : 1 } );
-basic1( { a : 1 , b : 1 } )
-basic1( { a : 1 } , { b : 1 } , true ) 
-basic1( { a : 1 , b : 1 } , { b : 1 , a : 1 } , true )
+basic1( { a : 1 , b : 1 } );
+basic1( { a : 1 } , { b : 1 } , true ); 
+basic1( { a : 1 , b : 1 } , { b : 1 , a : 1 } , true );
 basic1( { a : 1 } , { a : 2 } , true );
