@@ -6,9 +6,12 @@ N = 1000;
 
 function pop(){
     t.drop();
+    var arr = [];
     for ( var i=0; i<N; i++ ){
-        t.save( { x : 1 , tags : [ "a" , "b" , "c" ] } );
+        arr.push( { x : 1 , tags : [ "a" , "b" , "c" ] } );
     }
+    t.insert( arr );
+    assert.eq( t.count(), N );
 }
 
 function del(){
@@ -29,7 +32,7 @@ test( "a" );
 test( "b" , { x : 1 } );
 test( "c" , { tags : 1 } );
 
-N = 5000
+N = 5000;
 
 test( "a2" );
 test( "b2" , { x : 1 } );
