@@ -23,6 +23,6 @@ f.update( {}, {$set:{'_id':5}} );
 assert.eq( 0, f.findOne()._id , "D" );
 
 f.drop();
-f.save({_id:1, a:1})
-f.update({}, {$unset:{"a":1, "b.c":1}})
-assert.docEq(f.findOne(), {_id:1}, "E")
\ No newline at end of file
+f.save({_id:1, a:1});
+f.update({}, {$unset:{"a":1, "b.c":1}});
+assert.docEq(f.findOne(), {_id:1}, "E");
\ No newline at end of file
