@@ -4,22 +4,22 @@ var coll = db.update_mul;
 coll.drop();
 
 // $mul positive
-coll.remove({})
+coll.remove({});
 coll.save({_id:1, a:2});
-res = coll.update({}, {$mul: {a: 10}})
+res = coll.update({}, {$mul: {a: 10}});
 assert.writeOK(res);
-assert.eq(coll.findOne().a, 20)
+assert.eq(coll.findOne().a, 20);
 
 // $mul negative
-coll.remove({})
+coll.remove({});
 coll.save({_id:1, a:2});
-res = coll.update({}, {$mul: {a: -10}})
+res = coll.update({}, {$mul: {a: -10}});
 assert.writeOK(res);
-assert.eq(coll.findOne().a, -20)
+assert.eq(coll.findOne().a, -20);
 
 // $mul zero
-coll.remove({})
+coll.remove({});
 coll.save({_id:1, a:2});
-res = coll.update({}, {$mul: {a: 0}})
+res = coll.update({}, {$mul: {a: 0}});
 assert.writeOK(res);
-assert.eq(coll.findOne().a, 0)
+assert.eq(coll.findOne().a, 0);
