@@ -7,5 +7,5 @@ t.update( { "x.y" : 2 } , { $inc : { a : 7 } } , true );
 correct = { a : 7 , x : { y : 2 } };
 got = t.findOne();
 delete got._id;
-assert.docEq( correct , got , "A" )
+assert.docEq( correct , got , "A" );
 
