@@ -6,18 +6,22 @@ jsTest.log("Testing \"noprealloc\" command line option");
 var expectedResult = {
     "parsed" : {
         "storage" : {
-            "preallocDataFiles" : false
+            "mmapv1" : {
+                "preallocDataFiles" : false
+            }
         }
     }
 };
 testGetCmdLineOptsMongod({ noprealloc : "" }, expectedResult);
 
-jsTest.log("Testing \"storage.preallocDataFiles\" config file option");
+jsTest.log("Testing \"storage.mmapv1.preallocDataFiles\" config file option");
 expectedResult = {
     "parsed" : {
         "config" : "jstests/libs/config_files/enable_prealloc.json",
         "storage" : {
-            "preallocDataFiles" : true
+            "mmapv1" : {
+                "preallocDataFiles" : true
+            }
         }
     }
 };
@@ -32,4 +36,19 @@ expectedResult = {
 };
 testGetCmdLineOptsMongod({}, expectedResult);
 
+// Test that we preserve switches explicitly set to false in config files.  See SERVER-13439.
+jsTest.log("Testing explicitly disabled \"noprealloc\" config file option");
+expectedResult = {
+    "parsed" : {
+        "config" : "jstests/libs/config_files/disable_noprealloc.ini",
+        "storage" : {
+            "mmapv1" : {
+                "preallocDataFiles" : true
+            }
+        }
+    }
+};
+testGetCmdLineOptsMongod({ config : "jstests/libs/config_files/disable_noprealloc.ini" },
+                         expectedResult);
+
 print(baseName + " succeeded.");
