@@ -5,15 +5,15 @@
 */
 
 testname = "a_quick";
-tst = {}
+tst = {};
 
 tst.log = function (optional_msg) {
     print("\n\nstep " + ++this._step + " " + (optional_msg || ""));
-}
+};
 
 tst.success = function () {
     print(testname + " SUCCESS");
-}
+};
 
 /* diff files a and b, returning the difference (empty str if no difference) */
 tst.diff = function(a, b) {
@@ -33,7 +33,7 @@ tst.diff = function(a, b) {
     b = reSlash(b);
     print("diff " + a + " " + b);
     return run("diff", a, b);
-}
+};
 print(testname + " BEGIN");
 tst._step = 0;
 
@@ -59,21 +59,19 @@ var path2 = MongoRunner.dataDir + "/quickdur";
 
 // non-durable version
 tst.log("start mongod without dur");
-var conn = startMongodEmpty("--port", 30000, "--dbpath", path1, "--nodur");
+var conn = MongoRunner.runMongod({dbpath: path1, nojournal: ""});
 tst.log("without dur work");
 var d = conn.getDB("test");
-d.foo.insert({ _id:123 });
-d.getLastError();
+assert.writeOK(d.foo.insert({ _id: 123 }));
 tst.log("stop without dur");
-stopMongod(30000);
+MongoRunner.stopMongod(conn);
 
 // durable version
 tst.log("start mongod with dur");
-conn = startMongodEmpty("--port", 30001, "--dbpath", path2, "--dur", "--durOptions", 8);
+conn = MongoRunner.runMongod({dbpath: path2, journal: "", journalOptions: 8});
 tst.log("with dur work");
 d = conn.getDB("test");
-d.foo.insert({ _id: 123 });
-d.getLastError(); // wait
+assert.writeOK(d.foo.insert({ _id: 123 }));
 
 // we could actually do getlasterror fsync:1 now, but maybe this is agood 
 // as it will assure that commits happen on a timely basis.  a bunch of the other dur/*js
@@ -83,7 +81,7 @@ sleep(8000);
 
 // kill the process hard
 tst.log("kill -9 mongod");
-stopMongod(30001, /*signal*/9);
+MongoRunner.stopMongod(conn.port, /*signal*/9);
 
 // journal file should be present, and non-empty as we killed hard
 
@@ -106,7 +104,11 @@ if (files.some(function (f) { return f.name.indexOf("lsn") >= 0; })) {
 
 // restart and recover
 tst.log("restart and recover");
-conn = startMongodNoReset("--port", 30002, "--dbpath", path2, "--dur", "--durOptions", 9);
+conn = MongoRunner.runMongod({restart: true,
+                              cleanData: false,
+                              dbpath: path2,
+                              journal: "",
+                              journalOptions: 9});
 tst.log("check data results");
 d = conn.getDB("test");
 
@@ -117,7 +119,7 @@ if (!countOk) {
 }
 
 tst.log("stop");
-stopMongod(30002);
+MongoRunner.stopMongod(conn);
 
 // at this point, after clean shutdown, there should be no journal files
 tst.log("check no journal files");
