@@ -44,7 +44,7 @@ function checkNoJournalFiles(path, pass) {
 /** Clear dbpath without removing and recreating diskfulltest directory, as resetDbpath does */
 function clear() {
     files = listFiles( startPath );
-    files.forEach( function( x ) { removeFile( x.name ) } );
+    files.forEach( function( x ) { removeFile( x.name ); } );
 }
 
 function log(str) {
@@ -59,18 +59,15 @@ function work() {
     log("work");
     try {
         var d = conn.getDB("test");
-        
-        big = new Array( 5000 ).toString();
+        var big = new Array( 5000 ).toString();
+        var bulk = d.foo.initializeUnorderedBulkOp();
         // This part of the test depends on the partition size used in the build env
         // Currently, unused, but with larger partitions insert enough documents here
         // to create a second db file
         for( i = 0; i < 1; ++i ) {
-            d.foo.insert( { _id:i, b:big } );
+            bulk.insert({ _id: i, b: big });
         }
-        
-        gle = d.getLastError();
-        if ( gle )
-            throw gle;
+        assert.writeOK(bulk.execute());
     } catch ( e ) {
         print( e );
         raise( e );
@@ -97,10 +94,16 @@ function runFirstMongodAndFillDisk() {
     log();
     
     clear();
-    conn = startMongodNoReset("--port", 30001, "--dbpath", startPath, "--dur", "--smallfiles", "--durOptions", 8+64, "--noprealloc");
+    conn = MongoRunner.runMongod({restart: true,
+                                  cleanData: false,
+                                  dbpath: startPath,
+                                  journal: "",
+                                  smallfiles: "",
+                                  journalOptions: 8+64,
+                                  noprealloc: ""});
     
     assert.throws( work, null, "no exception thrown when exceeding disk capacity" );
-    stopMongod( 30001 );
+    MongoRunner.stopMongod(conn);
 
     sleep(5000);    
 }
@@ -108,11 +111,17 @@ function runFirstMongodAndFillDisk() {
 function runSecondMongdAndRecover() {
     // restart and recover
     log();
-    conn = startMongodNoReset("--port", 30003, "--dbpath", startPath, "--dur", "--smallfiles", "--durOptions", 8+64, "--noprealloc");
+    conn = MongoRunner.runMongod({restart: true,
+                                  cleanData: false,
+                                  dbpath: startPath,
+                                  journal: "",
+                                  smallfiles: "",
+                                  journalOptions: 8+64,
+                                  noprealloc: ""});
     verify();
     
     log("stop");
-    stopMongod(30003);
+    MongoRunner.stopMongod(conn);
     
     // stopMongod seems to be asynchronous (hmmm) so we sleep here.
     sleep(5000);
