@@ -1,5 +1,5 @@
 // perform inserts in parallel from several clients
-load('jstests/libs/parallelTester.js')
+load('jstests/libs/parallelTester.js');
 
 f = db.jstests_parallel_insert;
 f.drop();
