@@ -11,8 +11,7 @@ tm = dbm.bar;
 ts = dbs.bar;
 
 for ( var i=0; i<1000; i++ ){
-    tm.insert( { _id : i } );
-    dbm.runCommand( { getlasterror : 1 , w : 2 } )
+    tm.insert({ _id: i }, { writeConcern: { w: 2 }});
     assert.eq( i + 1 , ts.count() , "A" + i );
     assert.eq( i + 1 , tm.count() , "B" + i );
 }
