@@ -9,15 +9,14 @@ rt = new ReplTest( "repl12tests" );
 
 m = rt.start( true );
 
-usedDBs = []
+usedDBs = [];
 
-a = "a"
+a = "a";
 for( i = 0; i < 3; ++i ) {
-    usedDBs.push( a )
+    usedDBs.push( a );
     m.getDB( a ).c.save( {} );
     a += "a";
 }
-m.getDB(a).getLastError();
 
 //print("\n\n\n DB NAMES MASTER:");
 //printjson(m.getDBNames());
