@@ -1,4 +1,7 @@
 // check replica set authentication
+//
+// This test requires users to persist across a restart.
+// @tags: [requires_persistence]
 
 load("jstests/replsets/rslib.js");
 
@@ -6,86 +9,76 @@ var name = "rs_auth1";
 var port = allocatePorts(5);
 var path = "jstests/libs/";
 
+// These keyFiles have their permissions set to 600 later in the test.
+var key1_600 = path+"key1";
+var key2_600 = path+"key2";
+
+// This keyFile has its permissions set to 644 later in the test.
+var key1_644 = path+"key1_644";
 
 print("try starting mongod with auth");
 var m = MongoRunner.runMongod({auth : "", port : port[4], dbpath : MongoRunner.dataDir + "/wrong-auth"});
 
 assert.eq(m.getDB("local").auth("__system", ""), 0);
 
-stopMongod(port[4]);
+MongoRunner.stopMongod(m);
 
 
 print("reset permissions");
-run("chmod", "644", path+"key1");
-run("chmod", "644", path+"key2");
+run("chmod", "644", key1_644);
 
 
 print("try starting mongod");
-m = runMongoProgram( "mongod", "--keyFile", path+"key1", "--port", port[0], "--dbpath", MongoRunner.dataPath + name);
+m = runMongoProgram( "mongod", "--keyFile", key1_644, "--port", port[0], "--dbpath", MongoRunner.dataPath + name);
 
 
 print("should fail with wrong permissions");
 assert.eq(m, _isWindows()? 100 : 1, "mongod should exit w/ 1 (EXIT_FAILURE): permissions too open");
-stopMongod(port[0]);
-
-
-print("change permissions on #1 & #2");
-run("chmod", "600", path+"key1");
-run("chmod", "600", path+"key2");
-
+MongoRunner.stopMongod(port[0]);
 
 print("add a user to server0: foo");
-m = startMongodTest( port[0], name+"-0", 0 );
+m = MongoRunner.runMongod({dbpath: MongoRunner.dataPath + name + "-0"});
 m.getDB("admin").createUser({user: "foo", pwd: "bar", roles: jsTest.adminUserRoles});
 m.getDB("test").createUser({user: "bar", pwd: "baz", roles: jsTest.basicUserRoles});
 print("make sure user is written before shutting down");
-stopMongod(port[0]);
+MongoRunner.stopMongod(m);
 
 print("start up rs");
-var rs = new ReplSetTest({"name" : name, "nodes" : 3, "startPort" : port[0]});
+var rs = new ReplSetTest({"name" : name, "nodes" : 3});
 print("restart 0 with keyFile");
-m = rs.restart(0, {"keyFile" : path+"key1"});
+m = rs.restart(0, {"keyFile" : key1_600});
 print("restart 1 with keyFile");
-var s = rs.start(1, {"keyFile" : path+"key1"});
+rs.start(1, {"keyFile" : key1_600});
 print("restart 2 with keyFile");
-var s2 = rs.start(2, {"keyFile" : path+"key1"});
+rs.start(2, {"keyFile" : key1_600});
 
 var result = m.getDB("admin").auth("foo", "bar");
 assert.eq(result, 1, "login failed");
 print("Initializing replSet with config: " + tojson(rs.getReplSetConfig()));
 result = m.getDB("admin").runCommand({replSetInitiate : rs.getReplSetConfig()});
 assert.eq(result.ok, 1, "couldn't initiate: "+tojson(result));
+m.getDB('admin').logout(); // In case this node doesn't become primary, make sure its not auth'd
 
-var master = rs.getMaster().getDB("test");
-wait(function() {
-        var status = master.adminCommand({replSetGetStatus:1});
-        return status.members && status.members[1].state == 2 && status.members[2].state == 2;
-    });
-
-master.foo.insert({ x: 1 }, { writeConcern: { w:3, wtimeout:60000 }});
+var master = rs.getPrimary();
+rs.awaitSecondaryNodes();
+var mId = rs.getNodeId(master);
+var slave = rs.liveNodes.slaves[0];
+assert.eq(1, master.getDB("admin").auth("foo", "bar"));
+assert.writeOK(master.getDB("test").foo.insert({ x: 1 }, { writeConcern: { w:3, wtimeout:60000 }}));
 
 print("try some legal and illegal reads");
-var r = master.foo.findOne();
+var r = master.getDB("test").foo.findOne();
 assert.eq(r.x, 1);
 
-s.setSlaveOk();
-slave = s.getDB("test");
+slave.setSlaveOk();
 
 function doQueryOn(p) {
-    var err = {};
-    try {
-        r = p.foo.findOne();
-    }
-    catch(e) {
-        if (typeof(JSON) != "undefined") {
-            err = JSON.parse(e.substring(6));
-        }
-        else if (e.indexOf("13") > 0) {
-            err.code = 13;
-        }
-    }
-    assert.eq(err.code, 13);
-};
+    var error = assert.throws( function() {
+        r = p.getDB("test").foo.findOne();
+    }, [], "find did not throw, returned: " + tojson(r)).toString();
+    printjson(error);
+    assert.gt(error.indexOf("not authorized"), -1, "error was non-auth");
+}
 
 doQueryOn(slave);
 master.adminCommand({logout:1});
@@ -96,69 +89,55 @@ printjson(master.adminCommand({replSetGetStatus : 1}));
 doQueryOn(master);
 
 
-result = slave.auth("bar", "baz");
+result = slave.getDB("test").auth("bar", "baz");
 assert.eq(result, 1);
 
-r = slave.foo.findOne();
+r = slave.getDB("test").foo.findOne();
 assert.eq(r.x, 1);
 
 
 print("add some data");
-master.auth("bar", "baz");
-var bulk = master.foo.initializeUnorderedBulkOp();
+master.getDB("test").auth("bar", "baz");
+var bulk = master.getDB("test").foo.initializeUnorderedBulkOp();
 for (var i=0; i<1000; i++) {
     bulk.insert({ x: i, foo: "bar" });
 }
 assert.writeOK(bulk.execute({ w: 3, wtimeout: 60000 }));
 
 print("fail over");
-rs.stop(0);
-
-wait(function() {
-        function getMaster(s) {
-            var result = s.getDB("admin").runCommand({isMaster: 1});
-            printjson(result);
-            if (result.ismaster) {
-                master = s.getDB("test");
-                return true;
-            }
-            return false;
-        }
-
-        if (getMaster(s) || getMaster(s2)) {
-            return true;
-        }
-        return false;
-    });
+rs.stop(mId);
 
+master = rs.getPrimary();
 
 print("add some more data 1");
-master.auth("bar", "baz");
+master.getDB("test").auth("bar", "baz");
+bulk = master.getDB("test").foo.initializeUnorderedBulkOp();
 for (var i=0; i<1000; i++) {
-    master.foo.insert({x:i, foo : "bar"});
+    bulk.insert({ x: i, foo: "bar" });
 }
-var result = master.runCommand({getlasterror:1, w:2, wtimeout:60000});
-printjson(result);
-
+assert.writeOK(bulk.execute({ w: 2 }));
 
 print("resync");
-rs.restart(0, {"keyFile" : path+"key1"});
-
+rs.restart(mId, {"keyFile" : key1_600});
+master = rs.getPrimary();
 
 print("add some more data 2");
-var bulk = master.foo.initializeUnorderedBulkOp();
+bulk = master.getDB("test").foo.initializeUnorderedBulkOp();
 for (var i=0; i<1000; i++) {
     bulk.insert({ x: i, foo: "bar" });
 }
 bulk.execute({ w:3, wtimeout:60000 });
 
 print("add member with wrong key");
-var conn = new MongodRunner(port[3], MongoRunner.dataPath+name+"-3", null, null, ["--replSet","rs_auth1","--rest","--oplogSize","2", "--keyFile", path+"key2"], {no_bind : true});
-conn.start();
+var conn = MongoRunner.runMongod({dbpath: MongoRunner.dataPath + name + "-3",
+                                  port: port[3],
+                                  replSet: "rs_auth1",
+                                  oplogSize: 2,
+                                  keyFile: key2_600});
 
 
-master.getSisterDB("admin").auth("foo", "bar");
-var config = master.getSisterDB("local").system.replset.findOne();
+master.getDB("admin").auth("foo", "bar");
+var config = master.getDB("local").system.replset.findOne();
 config.members.push({_id : 3, host : rs.host+":"+port[3]});
 config.version++;
 try {
@@ -167,8 +146,8 @@ try {
 catch (e) {
     print("error: "+e);
 }
-reconnect(master);
-master.getSisterDB("admin").auth("foo", "bar");
+master = rs.getPrimary();
+master.getDB("admin").auth("foo", "bar");
 
 
 print("shouldn't ever sync");
@@ -182,12 +161,15 @@ for (var i = 0; i<10; i++) {
 
 
 print("stop member");
-stopMongod(port[3]);
+MongoRunner.stopMongod(conn);
 
 
 print("start back up with correct key");
-conn = new MongodRunner(port[3], MongoRunner.dataPath+name+"-3", null, null, ["--replSet","rs_auth1","--rest","--oplogSize","2", "--keyFile", path+"key1"], {no_bind : true});
-conn.start();
+var conn = MongoRunner.runMongod({dbpath: MongoRunner.dataPath + name + "-3",
+                                  port: port[3],
+                                  replSet: "rs_auth1",
+                                  oplogSize: 2,
+                                  keyFile: key1_600});
 
 wait(function() {
     try {
