@@ -1,16 +1,20 @@
-load("jstests/replsets/rslib.js");
 var ssl_options1;
 var ssl_options2;
-doTest = function( signal ) {
+var ssl_name;
+load("jstests/replsets/rslib.js");
+var doTest = function( signal ) {
 
     // Test basic replica set functionality.
     // -- Replication
     // -- Failover
 
-    // Replica set testing API
-    // Create a new replica set test. Specify set name and the number of nodes you want.
+
+
+    // Choose a name that is unique to the options specified.
+    // This is important because we are depending on a fresh replicaSetMonitor for each run;
+    // each differently-named replica set gets its own monitor. 
     // n0 and n1 get the same SSL config since there are 3 nodes but only 2 different configs
-    var replTest = new ReplSetTest( {name: 'testSet', nodes:
+    var replTest = new ReplSetTest( {name: 'testSet' + ssl_name, nodes:
                                     {n0: ssl_options1, n1: ssl_options1, n2: ssl_options2}});
 
     // call startSet() to start each mongod in the replica set
@@ -21,11 +25,18 @@ doTest = function( signal ) {
     // This will wait for initiation
     replTest.initiate();
 
-    // Call getMaster to return a reference to the node that's been
+    // Call getPrimary to return a reference to the node that's been
     // elected master.
-    var master = replTest.getMaster();
+    var master = replTest.getPrimary();
 
-    // Calling getMaster also makes available the liveNodes structure,
+    var isPV1 = (replTest.getConfigFromPrimary().protocolVersion == 1);
+    if (isPV1) {
+        // Ensure the primary logs an n-op to the oplog upon transitioning to primary.
+        var oplog_entry = master.getDB("local").oplog.rs.find().sort({$natural: -1})[0];
+        assert.eq("new primary", oplog_entry["o"]["msg"]);
+        assert.eq("n", oplog_entry["op"]);
+    }
+    // Calling getPrimary also makes available the liveNodes structure,
     // which looks like this:
     // liveNodes = {master: masterNode,
     //              slaves: [slave1, slave2]
@@ -40,7 +51,7 @@ doTest = function( signal ) {
     replTest.awaitReplication();
 
 
-    cppconn = new Mongo( replTest.getURL() ).getDB( "foo" );
+    var cppconn = new Mongo( replTest.getURL() ).getDB( "foo" );
     assert.eq( 1000 , cppconn.foo.findOne().a , "cppconn 1" );
 
     {
@@ -57,7 +68,7 @@ doTest = function( signal ) {
     replTest.stop( master_id );
 
     // Now let's see who the new master is:
-    var new_master = replTest.getMaster();
+    var new_master = replTest.getPrimary();
 
     // Is the new master the same as the old master?
     var new_master_id = replTest.getNodeId( new_master );
@@ -75,7 +86,7 @@ doTest = function( signal ) {
     bulk.execute();
 
     // Here's how to restart the old master node:
-    slave = replTest.restart(master_id);
+    var slave = replTest.restart(master_id);
 
 
     // Now, let's make sure that the old master comes up as a slave
@@ -93,11 +104,12 @@ doTest = function( signal ) {
     });
 
     // And that both slave nodes have all the updates
-    new_master = replTest.getMaster();
-    assert.eq( 1000 , new_master.getDB( "bar" ).runCommand( { count:"bar"} ).n , "assumption 2")
+    new_master = replTest.getPrimary();
+    assert.eq( 1000 , new_master.getDB( "bar" ).runCommand( { count:"bar"} ).n , "assumption 2");
+    replTest.awaitSecondaryNodes();
     replTest.awaitReplication();
 
-    slaves = replTest.liveNodes.slaves;
+    var slaves = replTest.liveNodes.slaves;
     assert( slaves.length == 2, "Expected 2 slaves but length was " + slaves.length );
     slaves.forEach(function(slave) {
         slave.setSlaveOk();
@@ -107,34 +119,40 @@ doTest = function( signal ) {
     });
 
     // last error
-    master = replTest.getMaster();
+    master = replTest.getPrimary();
     slaves = replTest.liveNodes.slaves;
     printjson(replTest.liveNodes);
 
-    db = master.getDB("foo")
-    t = db.foo
+    var db = master.getDB("foo");
+    var t = db.foo;
 
-    ts = slaves.map( function(z){ z.setSlaveOk(); return z.getDB( "foo" ).foo; } )
+    var ts = slaves.map( function(z){ z.setSlaveOk(); return z.getDB( "foo" ).foo; } );
 
     t.save({a: 1000});
-    t.ensureIndex( { a : 1 } )
+    t.ensureIndex( { a : 1 } );
 
-    result = db.runCommand({getLastError : 1, w: 3 , wtimeout :30000 })
+    var result = db.runCommand({getLastError : 1, w: 3 , wtimeout :30000 });
     printjson(result);
-    lastOp = result.lastOp;
-    lastOplogOp = master.getDB("local").oplog.rs.find().sort({$natural : -1}).limit(1).next();
-    assert.eq(lastOplogOp['ts'], lastOp);
+    var lastOp = result.lastOp;
+    var lastOplogOp = master.getDB("local").oplog.rs.find().sort({$natural : -1}).limit(1).next();
+    if (replTest.getConfigFromPrimary().protocolVersion != 1) {
+        assert.eq(lastOplogOp['ts'], lastOp);
+    }
+    else {
+        assert.eq(lastOplogOp['ts'], lastOp['ts']);
+        assert.eq(lastOplogOp['t'], lastOp['t']);
+    }
 
-    ts.forEach( function(z){ assert.eq( 2 , z.getIndexKeys().length , "A " + z.getMongo() ); } )
+    ts.forEach( function(z){ assert.eq( 2 , z.getIndexKeys().length , "A " + z.getMongo() ); } );
 
-    t.reIndex()
+    t.reIndex();
 
-    db.getLastError( 3 , 30000 )
-    ts.forEach( function(z){ assert.eq( 2 , z.getIndexKeys().length , "A " + z.getMongo() ); } )
+    db.getLastError( 3 , 30000 );
+    ts.forEach( function(z){ assert.eq( 2 , z.getIndexKeys().length , "A " + z.getMongo() ); } );
 
     // Shut down the set and finish the test.
     replTest.stopSet( signal );
-}
+};
 
 doTest( 15 );
 print("replset1.js SUCCESS");
