@@ -5,7 +5,7 @@ var rt = new ReplSetTest( { name : "replset7tests" , nodes: 1 } );
 
 var nodes = rt.startSet();
 rt.initiate();
-var master = rt.getMaster();
+var master = rt.getPrimary();
 
 var md = master.getDB( 'd' );
 var mdc = md[ 'c' ];
@@ -45,5 +45,9 @@ assert.writeOK(bulk.execute());
 rt.awaitSecondaryNodes();
 
 // Do we have an index?
-assert.eq (1, slave.getDB( 'd' )['system.indexes']
-           .find({"v" : 1,"key" : {"x" : 1},"unique" : true,"ns" : "d.c","name" : "x_1"}).count());
+assert.eq(1, slave.getDB( 'd' )['c'].getIndexes().filter(function (doc) {
+    return (doc.v === 1
+            && JSON.stringify(doc.key) === JSON.stringify({x: 1})
+            && doc.ns === 'd.c'
+            && doc.name === 'x_1');
+}).length);
