@@ -16,7 +16,7 @@ doTest = function( signal ) {
 
   replTest.initiate(config);
 
-  var master = replTest.getMaster().getDB(name);
+  var master = replTest.getPrimary().getDB(name);
   var slaveConns = replTest.liveNodes.slaves;
   var slaves = [];
   for (var i in slaveConns) {
@@ -66,7 +66,7 @@ doTest = function( signal ) {
   master = master.getSisterDB(name);
 
   // wait for the node to catch up
-  replTest.awaitReplication();
+  replTest.awaitReplication(90*1000);
 
   assert.writeOK(master.foo.insert({ _id: 123, x: 'foo' }, { writeConcern: { w: 2 }}));
 
@@ -77,7 +77,7 @@ doTest = function( signal ) {
 
   assert.soon(function() {
           var z = conn.getDB(name).foo.findOne({_id:123});
-          return z != null && z.x == "foo"
+          return z != null && z.x == "foo";
       });
 
   /************* Part 3 ******************/
@@ -88,7 +88,7 @@ doTest = function( signal ) {
   config.members[3].slaveDelay = 15;
 
   reconfig(replTest, config);
-  master = replTest.getMaster().getDB(name);
+  master = replTest.getPrimary().getDB(name);
   assert.soon(function() {
           return conn.getDB("local").system.replset.findOne().version == config.version;
       });
@@ -115,6 +115,6 @@ doTest = function( signal ) {
   }, 10*1000);
 
   replTest.stopSet();
-}
+};
 
 doTest(15);
