@@ -8,9 +8,9 @@ var c = replTest.getReplSetConfig();
 c.members[1].priority = 0; // not electable
 replTest.initiate(c);
 
-var master = replTest.getMaster();
+var master = replTest.getPrimary();
 var testDB = master.getDB('test');
-var firstPrimary = testDB.isMaster().primary
+var firstPrimary = testDB.isMaster().primary;
 
 // do a write to allow stepping down of the primary;
 // otherwise, the primary will refuse to step down
@@ -19,11 +19,12 @@ replTest.awaitReplication();
 
 // stepdown should fail since there is no-one to elect within 10 secs
 testDB.adminCommand({replSetStepDown:5});
-assert(master.getDB("a").isMaster().ismaster, "not master")
+assert(master.getDB("a").isMaster().ismaster, "not master");
 
 // step down the primary asyncronously so it doesn't kill this test
 var wait = startParallelShell("db.adminCommand({replSetStepDown:1000, force:true})", master.port);
-wait();
+var exitCode = wait({checkExitSuccess: false});
+assert.neq(0, exitCode, "expected replSetStepDown to close the shell's connection");
 
 // check that the old primary is no longer master
 assert.soon( function() {
@@ -34,7 +35,7 @@ assert.soon( function() {
     } catch (e) {
         return false;
     }
-  }, "they shouldn't be master, but are")
+  }, "they shouldn't be master, but are");
 
 // stop
 replTest.stopSet();
