@@ -2,6 +2,12 @@
  * This tests whether slaveOk reads are properly routed through mongos in
  * an authenticated environment. This test also includes restarting the
  * entire set, then querying afterwards.
+ *
+ * This test involves a full restart of the replica set, so cannot be run with ephemeral storage
+ * engines. When all nodes in a replica set are using an ephemeral storage engine, the set cannot
+ * recover from a full restart. Once restarted, the nodes will have no knowledge of the replica set
+ * config and will be unable to elect a primary.
+ * @tags: [requires_persistence]
  */
 
 /**
@@ -14,7 +20,9 @@
  */
 function doesRouteToSec( coll, query ) {
     var explain = coll.find( query ).explain();
-    var conn = new Mongo( explain.server );
+    assert.eq("SINGLE_SHARD", explain.queryPlanner.winningPlan.stage);
+    var serverInfo = explain.queryPlanner.winningPlan.shards[0].serverInfo;
+    var conn = new Mongo( serverInfo.host + ":" + serverInfo.port.toString());
     var cmdRes = conn.getDB( 'admin' ).runCommand({ isMaster: 1 });
 
     jsTest.log('isMaster: ' + tojson(cmdRes));
@@ -22,7 +30,7 @@ function doesRouteToSec( coll, query ) {
     return cmdRes.secondary;
 }
 
-var rsOpts = { oplogSize: 10 };
+var rsOpts = { oplogSize: 50 };
 var st = new ShardingTest({ keyFile: 'jstests/libs/key1', shards: 1,
     rs: rsOpts, other: { nopreallocj: 1 }});
 
@@ -37,7 +45,7 @@ var nodeCount = replTest.nodes.length;
  * connections to access the server from localhost connections if there
  * is no admin user.
  */
-var adminDB = mongos.getDB( 'admin' )
+var adminDB = mongos.getDB( 'admin' );
 adminDB.createUser({user: 'user', pwd: 'password', roles: jsTest.adminUserRoles});
 adminDB.auth( 'user', 'password' );
 var priAdminDB = replTest.getPrimary().getDB( 'admin' );
@@ -54,11 +62,11 @@ coll.setSlaveOk( true );
 ReplSetTest.awaitRSClientHosts( mongos, replTest.getSecondaries(),
    { ok : true, secondary : true });
 
+var bulk = coll.initializeUnorderedBulkOp();
 for ( var x = 0; x < 20; x++ ) {
-    coll.insert({ v: x, k: 10 });
+    bulk.insert({ v: x, k: 10 });
 }
-
-coll.runCommand({ getLastError: 1, w: nodeCount });
+assert.writeOK(bulk.execute({ w: nodeCount }));
 
 /* Although mongos never caches query results, try to do a different query
  * everytime just to be sure.
