@@ -1,10 +1,9 @@
-// features1.js
+(function() {
 
-s = new ShardingTest( "features1" , 2 , 1 , 1 );
-
-s.stopBalancer();
+var s = new ShardingTest({ name: "features1", shards: 2, mongos: 1 });
 
 s.adminCommand( { enablesharding : "test" } );
+s.ensurePrimaryShard('test', 'shard0001');
 
 // ---- can't shard system namespaces ----
 
@@ -60,17 +59,17 @@ assert.eq( 5 , b.foo.getIndexKeys().length , "c index 3" );
 
 db.foo2.ensureIndex( { a : 1 } );
 s.sync();
-printjson( db.system.indexes.find( { ns : "test.foo2" } ).toArray() );
+printjson( db.foo2.getIndexes() );
 assert( s.admin.runCommand( { shardcollection : "test.foo2" , key : { num : 1 } } ).ok , "shard with index" );
 
 db.foo3.ensureIndex( { a : 1 } , true );
 s.sync();
-printjson( db.system.indexes.find( { ns : "test.foo3" } ).toArray() );
+printjson( db.foo3.getIndexes() );
 assert( ! s.admin.runCommand( { shardcollection : "test.foo3" , key : { num : 1 } } ).ok , "shard with unique index" );
 
 db.foo7.ensureIndex( { num : 1 , a : 1 } , true );
 s.sync();
-printjson( db.system.indexes.find( { ns : "test.foo7" } ).toArray() );
+printjson( db.foo7.getIndexes() );
 assert( s.admin.runCommand( { shardcollection : "test.foo7" , key : { num : 1 } } ).ok , "shard with ok unique index" );
 
 
@@ -83,10 +82,10 @@ assert.eq( 1 , db.foo3.count() , "eval pre1" );
 assert.eq( 1 , db.foo2.count() , "eval pre2" );
 
 assert.eq( 8 , db.eval( function(){ return db.foo3.findOne().a; } ), "eval 1 " );
-assert.throws( function(){ db.eval( function(){ return db.foo2.findOne().a; } ) } , null , "eval 2" )
+assert.throws( function(){ db.eval( function(){ return db.foo2.findOne().a; } ); } , null , "eval 2" );
 
 assert.eq( 1 , db.eval( function(){ return db.foo3.count(); } ), "eval 3 " );
-assert.throws( function(){ db.eval( function(){ return db.foo2.count(); } ) } , null , "eval 4" )
+assert.throws( function(){ db.eval( function(){ return db.foo2.count(); } ); } , null , "eval 4" );
 
 // ----- "eval" new command name SERVER-5588 -----
 var result;
@@ -105,9 +104,8 @@ s.adminCommand( { split : "test.foo4" , middle : { num : 10 } } );
 s.admin.runCommand({ movechunk: "test.foo4", find: { num: 20 },
                      to: s.getOther( s.getServer( "test" ) ).name });
 
-db.foo4.save( { num : 5 } );
-db.foo4.save( { num : 15 } );
-db.getLastError();
+assert.writeOK(db.foo4.save( { num : 5 } ));
+assert.writeOK(db.foo4.save( { num : 15 } ));
 s.sync();
 assert.eq( 1 , a.foo4.count() , "ua1" );
 assert.eq( 1 , b.foo4.count() , "ub1" );
@@ -118,13 +116,11 @@ assert.eq( 2 , b.foo4.getIndexes().length , "ub2" );
 assert( a.foo4.getIndexes()[1].unique , "ua3" );
 assert( b.foo4.getIndexes()[1].unique , "ub3" );
 
-assert.eq( 2 , db.foo4.count() , "uc1" )
-db.foo4.save( { num : 7 } )
-assert.eq( 3 , db.foo4.count() , "uc2" )
-db.foo4.save( { num : 7 } )
-gle = db.getLastErrorObj();
-assert( gle.err , "uc3" )
-assert.eq( 3 , db.foo4.count() , "uc4" )
+assert.eq( 2 , db.foo4.count() , "uc1" );
+db.foo4.save( { num : 7 } );
+assert.eq( 3 , db.foo4.count() , "uc2" );
+assert.writeError(db.foo4.save( { num : 7 } ));
+assert.eq( 3 , db.foo4.count() , "uc4" );
 
 // --- don't let you convertToCapped ----
 assert( ! db.foo4.isCapped() , "ca1" );
@@ -145,7 +141,8 @@ assert( db.foo4a.isCapped() , "ca8" );
 
 db.createCollection("foo5", {capped:true, size:30000});
 assert( db.foo5.isCapped() , "cb1" );
-assert( ! s.admin.runCommand( { shardcollection : "test.foo5" , key : { num : 1 } } ).ok , "shard capped" );
+var res = s.admin.runCommand( { shardcollection : "test.foo5" , key : { num : 1 } } );
+assert( !res.ok , "shard capped: " + tojson( res ) );
 
 
 // ----- group ----
@@ -155,7 +152,7 @@ db.foo6.save( { a : 3 } );
 db.foo6.save( { a : 3 } );
 db.foo6.ensureIndex( { a : 1 } );
 s.sync();
-printjson( db.system.indexes.find( { ns : "test.foo6" } ).toArray() );
+printjson( db.foo6.getIndexes() );
 
 assert.eq( 2 , db.foo6.group( { key : { a : 1 } , initial : { count : 0 } , 
                                 reduce : function(z,prev){ prev.count++; } } ).length );
@@ -176,29 +173,28 @@ assert.soon( function() {
     return cmdRes.ok;
 }, 'move chunk test.foo6', 60000, 1000 );
 
-assert.throws( function(){ db.foo6.group( { key : { a : 1 } , initial : { count : 0 } , reduce : function(z,prev){ prev.count++; } } ); } );;
+assert.throws( function(){ db.foo6.group( { key : { a : 1 } , initial : { count : 0 } , reduce : function(z,prev){ prev.count++; } } ); } );
 
 
 // ---- can't shard non-empty collection without index -----
 
-db.foo8.save( { a : 1 } );
-db.getLastError();
+assert.writeOK(db.foo8.save( { a : 1 } ));
 assert( ! s.admin.runCommand( { shardcollection : "test.foo8" , key : { a : 1 } } ).ok , "non-empty collection" );
 
 
 // ---- can't shard non-empty collection with null values in shard key ----
 
-db.foo9.save( { b : 1 } );
-db.getLastError();
+assert.writeOK(db.foo9.save( { b : 1 } ));
 db.foo9.ensureIndex( { a : 1 } );
 assert( ! s.admin.runCommand( { shardcollection : "test.foo9" , key : { a : 1 } } ).ok , "entry with null value" );
 
 
 // --- listDatabases ---
 
-r = db.getMongo().getDBs()
-assert.eq( 3 , r.databases.length , "listDatabases 1 : " + tojson( r ) )
-assert.lt( 10000 , r.totalSize , "listDatabases 2 : " + tojson( r ) );
+r = db.getMongo().getDBs();
+assert.eq(2, r.databases.length, tojson(r));
+assert.eq( "number", typeof(r.totalSize) , "listDatabases 2 : " + tojson( r ) );
 
-s.stop()
+s.stop();
 
+})();
