@@ -1,9 +1,14 @@
-var st = new ShardingTest({ shards: 2, other: { shardOptions: { verbose: 1 }} });
-st.stopBalancer();
+(function() {
+
+var st = new ShardingTest({ shards: 2 });
 
 var configDB = st.s.getDB('config');
-configDB.adminCommand({ enableSharding: 'test' });
-configDB.adminCommand({ shardCollection: 'test.user', key: { x: 'hashed' }, numInitialChunks: 2 });
+assert.commandWorked(configDB.adminCommand({ enableSharding: 'test' }));
+
+st.ensurePrimaryShard('test', 'shard0001');
+assert.commandWorked(configDB.adminCommand({ shardCollection: 'test.user',
+                                             key: { x: 'hashed' },
+                                             numInitialChunks: 2 }));
 
 var metadata = st.d0.getDB('admin').runCommand({ getShardVersion: 'test.user',
                                                  fullMetadata: true });
@@ -18,3 +23,4 @@ assert(bsonWoCompare(chunks[0][0], chunks[0][1]) < 0, tojson(metadata));
 
 st.stop();
 
+})();
