@@ -10,13 +10,10 @@
 // sequence), idle (connection is connected but not used before a shard change), and new
 // (connection connected after shard change).
 //
+(function() {
+'use strict';
 
-var options = {separateConfig : true,
-               rs : true,
-               rsOptions : { nodes : 2 }};
-
-var st = new ShardingTest({shards : 3, mongos : 1, other : options});
-st.stopBalancer();
+var st = new ShardingTest({ shards: 3, mongos: 1, other: { rs: true, rsOptions: { nodes: 2 } } });
 
 var mongos = st.s0;
 var admin = mongos.getDB( "admin" );
@@ -28,10 +25,8 @@ var collSharded = mongos.getCollection( "fooSharded.barSharded" );
 var collUnsharded = mongos.getCollection( "fooUnsharded.barUnsharded" );
 
 // Create the unsharded database
-collUnsharded.insert({ some : "doc" });
-assert.eq( null, collUnsharded.getDB().getLastError() );
-collUnsharded.remove({});
-assert.eq( null, collUnsharded.getDB().getLastError() );
+assert.writeOK(collUnsharded.insert({ some : "doc" }));
+assert.writeOK(collUnsharded.remove({}));
 printjson( admin.runCommand({ movePrimary : collUnsharded.getDB().toString(),
                               to : shards[0]._id }) );
 
@@ -47,21 +42,6 @@ assert.commandWorked( admin.runCommand({ moveChunk : collSharded.toString(),
 
 st.printShardingStatus();
 
-// Needed b/c the GLE command itself can fail if the shard is down ("write result unknown") - we
-// don't care if this happens in this test, we only care that we did not get "write succeeded".
-// Depending on the connection pool state, we could get either.
-function gleErrorOrThrow(database, msg) {
-    var gle;
-    try {
-        gle = database.getLastErrorObj();
-    }
-    catch (ex) {
-        return;
-    }
-    if (!gle.err) doassert("getLastError is null: " + tojson(gle) + " :" + msg);
-    return;
-};
-
 //
 // Setup is complete
 //
@@ -72,18 +52,17 @@ var mongosConnActive = new Mongo( mongos.host );
 var mongosConnIdle = null;
 var mongosConnNew = null;
 
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -1 });
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 1 });
-assert.eq(null, mongosConnActive.getCollection( collSharded.toString() ).getDB().getLastError());
+var wc = {writeConcern: {w: 2, wtimeout: 60000}};
 
-mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 1 });
-assert.eq(null, mongosConnActive.getCollection( collUnsharded.toString() ).getDB().getLastError());
+assert.writeOK(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -1 }, wc));
+assert.writeOK(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 1 }, wc));
+assert.writeOK(mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 1 }, wc));
 
 jsTest.log("Stopping primary of third shard...");
 
 mongosConnIdle = new Mongo( mongos.host );
 
-st.rs2.stop(st.rs2.getPrimary(), true /*wait for stop*/ );
+st.rs2.stop(st.rs2.getPrimary());
 
 jsTest.log("Testing active connection with third primary down...");
 
@@ -91,21 +70,15 @@ assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOn
 assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOne({ _id : 1 }));
 assert.neq(null, mongosConnActive.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -2 });
-assert.gleSuccess(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 2 });
-assert.gleSuccess(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 2 });
-assert.gleSuccess(mongosConnActive.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -2 }, wc));
+assert.writeOK(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 2 }, wc));
+assert.writeOK(mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 2 }, wc));
 
 jsTest.log("Testing idle connection with third primary down...");
 
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -3 });
-assert.gleSuccess(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 3 });
-assert.gleSuccess(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 3 });
-assert.gleSuccess(mongosConnIdle.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -3 }, wc));
+assert.writeOK(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 3 }, wc));
+assert.writeOK(mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 3 }, wc));
 
 assert.neq(null, mongosConnIdle.getCollection( collSharded.toString() ).findOne({ _id : -1 }) );
 assert.neq(null, mongosConnIdle.getCollection( collSharded.toString() ).findOne({ _id : 1 }) );
@@ -121,14 +94,11 @@ mongosConnNew = new Mongo( mongos.host );
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }) );
 
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -4 });
-assert.gleSuccess(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeOK(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -4 }, wc));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 4 });
-assert.gleSuccess(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeOK(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 4 }, wc));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 4 });
-assert.gleSuccess(mongosConnNew.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 4 }, wc));
 
 gc(); // Clean up new connections
 
@@ -139,7 +109,7 @@ mongosConnIdle = new Mongo( mongos.host );
 // Need to save this node for later
 var rs1Secondary = st.rs1.getSecondary();
 
-st.rs1.stop(st.rs1.getPrimary(), true /* wait for stop */);
+st.rs1.stop(st.rs1.getPrimary());
 
 jsTest.log("Testing active connection with second primary down...");
 
@@ -188,22 +158,16 @@ assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOn
 assert.neq(null, mongosConnActive.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
 // Writes
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -5 });
-assert.gleSuccess(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 5 });
-gleErrorOrThrow(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 5 });
-assert.gleSuccess(mongosConnActive.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -5 }, wc));
+assert.writeError(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 5 }, wc));
+assert.writeOK(mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 5 }, wc));
 
 jsTest.log("Testing idle connection with second primary down...");
 
 // Writes
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -6 });
-assert.gleSuccess(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 6 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 6 });
-assert.gleSuccess(mongosConnIdle.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -6 }, wc));
+assert.writeError(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 6 }, wc));
+assert.writeOK(mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 6 }, wc));
 
 // Reads with read prefs
 mongosConnIdle.setSlaveOk();
@@ -262,6 +226,8 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setSlaveOk();
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }) );
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("primary");
 assert.neq(null, mongosConnNew.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
@@ -274,6 +240,8 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("primary");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 // Ensure read prefs override slaveok
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setSlaveOk();
@@ -290,6 +258,8 @@ mongosConnNew.setSlaveOk();
 mongosConnNew.setReadPref("primary");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("secondary");
 assert.neq(null, mongosConnNew.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
@@ -300,6 +270,8 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("secondary");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("primaryPreferred");
 assert.neq(null, mongosConnNew.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
@@ -310,6 +282,8 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("primaryPreferred");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("secondaryPreferred");
 assert.neq(null, mongosConnNew.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
@@ -320,6 +294,8 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("secondaryPreferred");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("nearest");
 assert.neq(null, mongosConnNew.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
@@ -330,16 +306,15 @@ mongosConnNew = new Mongo( mongos.host );
 mongosConnNew.setReadPref("nearest");
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
+gc(); // Clean up new connections incrementally to compensate for slow win32 machine.
+
 // Writes
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -7 });
-assert.gleSuccess(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeOK(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -7 }, wc));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 7 });
-gleErrorOrThrow(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 7 }, wc));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 7 });
-assert.gleSuccess(mongosConnNew.getCollection( collUnsharded.toString() ).getDB());
+assert.writeOK(mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 7 }, wc));
 
 gc(); // Clean up new connections
 
@@ -347,7 +322,7 @@ jsTest.log("Stopping primary of first shard...");
 
 mongosConnIdle = new Mongo( mongos.host );
 
-st.rs0.stop(st.rs0.getPrimary(), true /*wait for stop*/ );
+st.rs0.stop(st.rs0.getPrimary());
 
 jsTest.log("Testing active connection with first primary down...");
 
@@ -356,21 +331,15 @@ assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOn
 assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOne({ _id : 1 }));
 assert.neq(null, mongosConnActive.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -8 });
-gleErrorOrThrow(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 8 });
-gleErrorOrThrow(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 8 });
-gleErrorOrThrow(mongosConnActive.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -8 }));
+assert.writeError(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 8 }));
+assert.writeError(mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 8 }));
 
 jsTest.log("Testing idle connection with first primary down...");
 
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -9 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 9 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 9 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -9 }));
+assert.writeError(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 9 }));
+assert.writeError(mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 9 }));
 
 mongosConnIdle.setSlaveOk();
 assert.neq(null, mongosConnIdle.getCollection( collSharded.toString() ).findOne({ _id : -1 }) );
@@ -390,14 +359,11 @@ mongosConnNew.setSlaveOk();
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }) );
 
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -10 });
-gleErrorOrThrow(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -10 }));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 10 });
-gleErrorOrThrow(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 10 }));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 10 });
-gleErrorOrThrow(mongosConnNew.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 10 }));
 
 gc(); // Clean up new connections
 
@@ -405,7 +371,7 @@ jsTest.log("Stopping second shard...");
 
 mongosConnIdle = new Mongo( mongos.host );
 
-st.rs1.stop(rs1Secondary, true /* wait for stop */);
+st.rs1.stop(rs1Secondary);
 
 jsTest.log("Testing active connection with second shard down...");
 
@@ -413,21 +379,15 @@ mongosConnActive.setSlaveOk();
 assert.neq(null, mongosConnActive.getCollection( collSharded.toString() ).findOne({ _id : -1 }));
 assert.neq(null, mongosConnActive.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }));
 
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -11 });
-gleErrorOrThrow(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 11 });
-gleErrorOrThrow(mongosConnActive.getCollection( collSharded.toString() ).getDB());
-mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 11 });
-gleErrorOrThrow(mongosConnActive.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : -11 }));
+assert.writeError(mongosConnActive.getCollection( collSharded.toString() ).insert({ _id : 11 }));
+assert.writeError(mongosConnActive.getCollection( collUnsharded.toString() ).insert({ _id : 11 }));
 
 jsTest.log("Testing idle connection with second shard down...");
 
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -12 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 12 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collSharded.toString() ).getDB());
-mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 12 });
-gleErrorOrThrow(mongosConnIdle.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : -12 }));
+assert.writeError(mongosConnIdle.getCollection( collSharded.toString() ).insert({ _id : 12 }));
+assert.writeError(mongosConnIdle.getCollection( collUnsharded.toString() ).insert({ _id : 12 }));
 
 mongosConnIdle.setSlaveOk();
 assert.neq(null, mongosConnIdle.getCollection( collSharded.toString() ).findOne({ _id : -1 }) );
@@ -443,21 +403,14 @@ mongosConnNew.setSlaveOk();
 assert.neq(null, mongosConnNew.getCollection( collUnsharded.toString() ).findOne({ _id : 1 }) );
 
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -13 });
-gleErrorOrThrow(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : -13 }));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 13 });
-gleErrorOrThrow(mongosConnNew.getCollection( collSharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collSharded.toString() ).insert({ _id : 13 }));
 mongosConnNew = new Mongo( mongos.host );
-mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 13 });
-gleErrorOrThrow(mongosConnNew.getCollection( collUnsharded.toString() ).getDB());
+assert.writeError(mongosConnNew.getCollection( collUnsharded.toString() ).insert({ _id : 13 }));
 
 gc(); // Clean up new connections
 
-jsTest.log("DONE!");
 st.stop();
 
-
-
-
-
+})();
