@@ -6,6 +6,7 @@ function setupMoveChunkTest(st) {
     var testcoll = testdb.foo;
 
     st.adminCommand( { enablesharding : "test" } );
+    st.ensurePrimaryShard('test', 'shard0001');
     st.adminCommand( { shardcollection : "test.foo" , key : { _id : 1 } } );
 
     var str = "";
@@ -13,22 +14,22 @@ function setupMoveChunkTest(st) {
         str += "asdasdsdasdasdasdas";
     }
 
-    var data = num = 0;
+    var data = 0;
+    var num = 0;
 
     //Insert till you get to 10MB of data
+    var bulk = testcoll.initializeUnorderedBulkOp();
     while ( data < ( 1024 * 1024 * 10 ) ) {
-        testcoll.insert( { _id : num++ , s : str } )
-        data += str.length
+        bulk.insert({ _id: num++, s: str });
+        data += str.length;
     }
+    assert.writeOK(bulk.execute());
 
-    //Flush and wait
-    testdb.getLastError()
-
-    var stats = st.chunkCounts( "foo" )
-    var to = ""
+    var stats = st.chunkCounts( "foo" );
+    var to = "";
     for ( shard in stats ){
         if ( stats[shard] == 0 ) {
-            to = shard
+            to = shard;
             break;
         }
     }
@@ -36,5 +37,5 @@ function setupMoveChunkTest(st) {
                                     find : { _id : 1 } ,
                                     to : to ,
                                     _waitForDelete : true} ); //some tests need this...
-    assert(result, "movechunk failed: " + tojson( result ) )
+    assert(result, "movechunk failed: " + tojson( result ) );
 }
