@@ -2,7 +2,7 @@
 * this tests some of the ground work
 */
 
-s = new ShardingTest( "shard1" , 2 );
+s = new ShardingTest({name: "shard1", shards: 2});
 
 db = s.getDB( "test" );
 db.foo.insert( { num : 1 , name : "eliot" } );
@@ -16,6 +16,7 @@ shardCommand = { shardcollection : "test.foo" , key : { num : 1 } };
 assert.throws( function(){ s.adminCommand( shardCommand ); } );
 
 s.adminCommand( { enablesharding : "test" } );
+s.ensurePrimaryShard('test', 'shard0001');
 assert.eq( 3 , db.foo.find().length() , "after partitioning count failed" );
 
 s.adminCommand( shardCommand );
@@ -23,14 +24,18 @@ s.adminCommand( shardCommand );
 assert.throws( function(){ s.adminCommand({ shardCollection: 'test', key: { x: 1 }}); });
 assert.throws( function(){ s.adminCommand({ shardCollection: '.foo', key: { x: 1 }}); });
 
-cconfig = s.config.collections.findOne( { _id : "test.foo" } );
-assert( cconfig , "why no collection entry for test.foo" )
-delete cconfig.lastmod
-delete cconfig.dropped
-delete cconfig.lastmodEpoch
-assert.eq( cconfig , { _id : "test.foo" , key : { num : 1 } , unique : false } , "Sharded content" );
+var cconfig = s.config.collections.findOne( { _id : "test.foo" } );
+assert( cconfig , "why no collection entry for test.foo" );
 
-s.config.collections.find().forEach( printjson )
+delete cconfig.lastmod;
+delete cconfig.dropped;
+delete cconfig.lastmodEpoch;
+
+assert.eq(cconfig,
+          { _id : "test.foo" , key : { num : 1 } , unique : false },
+          "Sharded content mismatch");
+
+s.config.collections.find().forEach( printjson );
 
 assert.eq( 1 , s.config.chunks.count() , "num chunks A");
 si = s.config.chunks.findOne();
@@ -39,12 +44,4 @@ assert.eq( si.ns , "test.foo" );
 
 assert.eq( 3 , db.foo.find().length() , "after sharding, no split count failed" );
 
-// SERVER-4284, test modified because of SERVER-5020
-var invalidDB = s.getDB( "foobar" );
-// hack to bypass invalid database name checking at the DB constructor
-invalidDB._name = "foo bar";
-invalidDB.blah.insert( { x : 1 } );
-assert.isnull( s.config.databases.findOne( { _id : "foo bar" } ) );
-
-
 s.stop();
