@@ -31,39 +31,49 @@
 #pragma once
 
 #include "mongo/db/commands.h"
+#include "mongo/stdx/mutex.h"
 
 namespace mongo {
 
-    void logOpForDbHash( const char* opstr,
-                         const char* ns,
-                         const BSONObj& obj,
-                         BSONObj* patt,
-                         const BSONObj* fullObj,
-                         bool forMigrateCleanup );
+void logOpForDbHash(OperationContext* txn, const char* ns);
 
-    class DBHashCmd : public Command {
-    public:
-        DBHashCmd();
+class DBHashCmd : public Command {
+public:
+    DBHashCmd();
 
-        virtual bool slaveOk() const { return true; }
-        virtual LockType locktype() const { return READ; }
-        virtual void addRequiredPrivileges(const std::string& dbname,
-                                           const BSONObj& cmdObj,
-                                           std::vector<Privilege>* out);
+    virtual bool slaveOk() const {
+        return true;
+    }
+    virtual bool isWriteCommandForConfigServer() const {
+        return false;
+    }
+    virtual void addRequiredPrivileges(const std::string& dbname,
+                                       const BSONObj& cmdObj,
+                                       std::vector<Privilege>* out);
 
-        virtual bool run(const string& dbname , BSONObj& cmdObj, int, string& errmsg, BSONObjBuilder& result, bool);
+    virtual bool run(OperationContext* txn,
+                     const std::string& dbname,
+                     BSONObj& cmdObj,
+                     int,
+                     std::string& errmsg,
+                     BSONObjBuilder& result);
 
-        void wipeCacheForCollection( const StringData& ns );
+    void wipeCacheForCollection(OperationContext* txn, StringData ns);
 
-    private:
+private:
+    /**
+     * RecoveryUnit::Change subclass used to commit work for dbhash logOp listener
+     */
+    class DBHashLogOpHandler;
 
-        bool isCachable( const StringData& ns ) const;
+    bool isCachable(StringData ns) const;
 
-        string hashCollection( const string& fullCollectionName, bool* fromCache );
-
-        map<string,string> _cachedHashed;
-        mutex _cachedHashedMutex;
-
-    };
+    std::string hashCollection(OperationContext* opCtx,
+                               Database* db,
+                               const std::string& fullCollectionName,
+                               bool* fromCache);
 
+    std::map<std::string, std::string> _cachedHashed;
+    stdx::mutex _cachedHashedMutex;
+};
 }
