@@ -2,19 +2,19 @@
 if (typeof(Timestamp) != "undefined"){
     Timestamp.prototype.tojson = function() {
         return this.toString();
-    }
+    };
 
     Timestamp.prototype.getTime = function() {
         return this.t;
-    }
+    };
 
     Timestamp.prototype.getInc = function() {
         return this.i;
-    }
+    };
 
     Timestamp.prototype.toString = function() {
         return "Timestamp(" + this.t + ", " + this.i + ")";
-    }
+    };
 }
 else {
     print("warning: no Timestamp class");
@@ -28,7 +28,7 @@ Date.timeFunc = function(theFunc, numTimes){
     }
 
     return (new Date()).getTime() - start.getTime();
-}
+};
 
 Date.prototype.tojson = function(){
     var UTC = 'UTC';
@@ -37,10 +37,10 @@ Date.prototype.tojson = function(){
     var date = this['get'+UTC+'Date']().zeroPad(2);
     var hour = this['get'+UTC+'Hours']().zeroPad(2);
     var minute = this['get'+UTC+'Minutes']().zeroPad(2);
-    var sec = this['get'+UTC+'Seconds']().zeroPad(2)
+    var sec = this['get'+UTC+'Seconds']().zeroPad(2);
 
     if (this['get'+UTC+'Milliseconds']())
-        sec += '.' + this['get'+UTC+'Milliseconds']().zeroPad(3)
+        sec += '.' + this['get'+UTC+'Milliseconds']().zeroPad(3);
 
     var ofs = 'Z';
     // // print a non-UTC time
@@ -51,7 +51,7 @@ Date.prototype.tojson = function(){
     //     ofs += (ofsmin%60).zeroPad(2)
     // }
     return 'ISODate("'+year+'-'+month+'-'+date+'T'+hour+':'+minute+':'+sec+ofs+'")';
-}
+};
 
 ISODate = function(isoDateStr){
     if (!isoDateStr)
@@ -61,7 +61,7 @@ ISODate = function(isoDateStr){
     var res = isoDateRegex.exec(isoDateStr);
 
     if (!res)
-        throw "invalid ISO date";
+        throw Error("invalid ISO date");
 
     var year = parseInt(res[1],10) || 1970; // this should always be present
     var month = (parseInt(res[2],10) || 1) - 1;
@@ -101,29 +101,37 @@ ISODate = function(isoDateStr){
         if (res[12] == '+') // if ahead subtract
             ofs *= -1;
 
-        time += ofs
+        time += ofs;
     }
 
     return new Date(time);
-}
+};
 
 // Regular Expression
 RegExp.escape = function(text){
     return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
-}
+};
 
 RegExp.prototype.tojson = RegExp.prototype.toString;
 
 // Array
 Array.contains = function(a, x){
+    if (!Array.isArray(a)) {
+        throw new Error("The first argument to Array.contains must be an array");
+    }
+
     for (var i=0; i<a.length; i++){
         if (a[i] == x)
             return true;
     }
     return false;
-}
+};
 
 Array.unique = function(a){
+    if (!Array.isArray(a)) {
+        throw new Error("The first argument to Array.unique must be an array");
+    }
+
     var u = [];
     for (var i=0; i<a.length; i++){
         var o = a[i];
@@ -132,9 +140,13 @@ Array.unique = function(a){
         }
     }
     return u;
-}
+};
 
 Array.shuffle = function(arr){
+    if (!Array.isArray(arr)) {
+        throw new Error("The first argument to Array.shuffle must be an array");
+    }
+
     for (var i=0; i<arr.length-1; i++){
         var pos = i+Random.randInt(arr.length-i);
         var save = arr[i];
@@ -142,10 +154,14 @@ Array.shuffle = function(arr){
         arr[pos] = save;
     }
     return arr;
-}
+};
 
 Array.tojson = function(a, indent, nolint){
-    var lineEnding = nolint ? " " : "\n";
+    if (!Array.isArray(a)) {
+        throw new Error("The first argument to Array.tojson must be an array");
+    }
+
+    var elementSeparator = nolint ? " " : "\n";
 
     if (!indent)
         indent = "";
@@ -156,24 +172,32 @@ Array.tojson = function(a, indent, nolint){
         return "[ ]";
     }
 
-    var s = "[" + lineEnding;
-    indent += "\t";
+    var s = "[" + elementSeparator;
+
+    // add to indent if we are pretty
+    if (!nolint)
+      indent += "\t";
+
     for (var i=0; i<a.length; i++){
         s += indent + tojson(a[i], indent, nolint);
         if (i < a.length - 1){
-            s += "," + lineEnding;
+            s += "," + elementSeparator;
         }
     }
-    if (a.length == 0) {
-        s += indent;
-    }
 
-    indent = indent.substring(1);
-    s += lineEnding+indent+"]";
+    // remove from indent if we are pretty
+    if (!nolint)
+      indent = indent.substring(1);
+
+    s += elementSeparator + indent + "]";
     return s;
-}
+};
 
 Array.fetchRefs = function(arr, coll){
+    if (!Array.isArray(arr)) {
+        throw new Error("The first argument to Array.fetchRefs must be an array");
+    }
+
     var n = [];
     for (var i=0; i<arr.length; i ++){
         var z = arr[i];
@@ -182,24 +206,36 @@ Array.fetchRefs = function(arr, coll){
         n.push(z.fetch());
     }
     return n;
-}
+};
 
 Array.sum = function(arr){
+    if (!Array.isArray(arr)) {
+        throw new Error("The first argument to Array.sum must be an array");
+    }
+
     if (arr.length == 0)
         return null;
     var s = arr[0];
     for (var i=1; i<arr.length; i++)
         s += arr[i];
     return s;
-}
+};
 
 Array.avg = function(arr){
+    if (!Array.isArray(arr)) {
+        throw new Error("The first argument to Array.avg must be an array");
+    }
+
     if (arr.length == 0)
         return null;
     return Array.sum(arr) / arr.length;
-}
+};
 
 Array.stdDev = function(arr){
+    if (!Array.isArray(arr)) {
+        throw new Error("The first argument to Array.stdDev must be an array");
+    }
+
     var avg = Array.avg(arr);
     var sum = 0;
 
@@ -208,20 +244,16 @@ Array.stdDev = function(arr){
     }
 
     return Math.sqrt(sum / arr.length);
-}
-
-if (typeof Array.isArray != "function"){
-    Array.isArray = function(arr){
-        return arr != undefined && arr.constructor == Array
-    }
-}
+};
 
 // Object
 Object.extend = function(dst, src, deep){
     for (var k in src){
         var v = src[k];
         if (deep && typeof(v) == "object"){
-            if ("floatApprox" in v) { // convert NumberLong properly
+            if (v.constructor === ObjectId) { // convert ObjectId properly
+                eval("v = " + tojson(v));
+            } else if ("floatApprox" in v) { // convert NumberLong properly
                 eval("v = " + tojson(v));
             } else {
                 v = Object.extend(typeof (v.length) == "number" ? [] : {}, v, true);
@@ -230,12 +262,12 @@ Object.extend = function(dst, src, deep){
         dst[k] = v;
     }
     return dst;
-}
+};
 
 Object.merge = function(dst, src, deep){
-    var clone = Object.extend({}, dst, deep)
-    return Object.extend(clone, src, deep)
-}
+    var clone = Object.extend({}, dst, deep);
+    return Object.extend(clone, src, deep);
+};
 
 Object.keySet = function(o) {
     var ret = new Array();
@@ -245,23 +277,23 @@ Object.keySet = function(o) {
         }
     }
     return ret;
-}
+};
 
 // String
 if (String.prototype.trim === undefined) {
     String.prototype.trim = function() {
         return this.replace(/^\s+|\s+$/g,"");
-    }
+    };
 }
 if (String.prototype.trimLeft === undefined) {
     String.prototype.trimLeft = function() {
         return this.replace(/^\s+/,"");
-    }
+    };
 }
 if (String.prototype.trimRight === undefined) {
     String.prototype.trimRight = function() {
         return this.replace(/\s+$/,"");
-    }
+    };
 }
 
 // always provide ltrim and rtrim for backwards compatibility
@@ -269,11 +301,19 @@ String.prototype.ltrim = String.prototype.trimLeft;
 String.prototype.rtrim = String.prototype.trimRight;
 
 String.prototype.startsWith = function(str){
-    return this.indexOf(str) == 0
-}
+    return this.indexOf(str) == 0;
+};
 
 String.prototype.endsWith = function(str){
-    return new RegExp(RegExp.escape(str) + "$").test(this)
+    return this.indexOf(str, this.length - str.length) !== -1;
+};
+
+// Polyfill taken from
+// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/includes
+if (!String.prototype.includes) {
+    String.prototype.includes = function() {'use strict';
+        return String.prototype.indexOf.apply(this, arguments) !== -1;
+    };
 }
 
 // Returns a copy padded with the provided character _chr_ so it becomes (at least) _length_
@@ -294,60 +334,102 @@ String.prototype.pad = function(length, right, chr) {
         }
     }
     return str;
-}
+};
 
 // Number
 Number.prototype.toPercentStr = function() {
     return (this * 100).toFixed(2) + "%";
-}
+};
 
 Number.prototype.zeroPad = function(width) {
     return ('' + this).pad(width, false, '0');
-}
+};
 
 // NumberLong
 if (! NumberLong.prototype) {
-    NumberLong.prototype = {}
+    NumberLong.prototype = {};
 }
 
 NumberLong.prototype.tojson = function() {
     return this.toString();
-}
+};
 
 // NumberInt
 if (! NumberInt.prototype) {
-    NumberInt.prototype = {}
+    NumberInt.prototype = {};
 }
 
 NumberInt.prototype.tojson = function() {
     return this.toString();
+};
+
+// NumberDecimal
+if (typeof NumberDecimal !== 'undefined') {
+    if (! NumberDecimal.prototype) {
+        NumberDecimal.prototype = {};
+    }
+
+    NumberDecimal.prototype.tojson = function() {
+        return this.toString();
+    };
 }
 
 // ObjectId
 if (! ObjectId.prototype)
-    ObjectId.prototype = {}
+    ObjectId.prototype = {};
 
 ObjectId.prototype.toString = function(){
     return "ObjectId(" + tojson(this.str) + ")";
-}
+};
 
 ObjectId.prototype.tojson = function(){
     return this.toString();
-}
+};
 
 ObjectId.prototype.valueOf = function(){
     return this.str;
-}
+};
 
 ObjectId.prototype.isObjectId = true;
 
 ObjectId.prototype.getTimestamp = function(){
     return new Date(parseInt(this.valueOf().slice(0,8), 16)*1000);
-}
+};
 
 ObjectId.prototype.equals = function(other){
     return this.str == other.str;
-}
+};
+
+// Creates an ObjectId from a Date.
+// Based on solution discussed here:
+//     http://stackoverflow.com/questions/8749971/can-i-query-mongodb-objectid-by-date
+ObjectId.fromDate = function(source) {
+    if (!source) {
+        throw Error("date missing or undefined");
+    }
+
+    var sourceDate;
+
+    // Extract Date from input.
+    // If input is a string, assume ISO date string and
+    // create a Date from the string.
+    if (source instanceof Date) {
+        sourceDate = source;
+    } else {
+        throw Error("Cannot create ObjectId from " + typeof(source) + ": " + tojson(source));
+    }
+
+    // Convert date object to seconds since Unix epoch.
+    var seconds = Math.floor(sourceDate.getTime()/1000);
+
+    // Generate hex timestamp with padding.
+    var hexTimestamp = seconds.toString(16).pad(8,false,'0') + "0000000000000000";
+
+    // Create an ObjectId with hex timestamp.
+    var objectId = ObjectId(hexTimestamp);
+
+    return objectId;
+};
 
 // DBPointer
 if (typeof(DBPointer) != "undefined"){
@@ -355,23 +437,23 @@ if (typeof(DBPointer) != "undefined"){
         assert(this.ns, "need a ns");
         assert(this.id, "need an id");
         return db[ this.ns ].findOne({ _id : this.id });
-    }
+    };
 
     DBPointer.prototype.tojson = function(indent){
         return this.toString();
-    }
+    };
 
     DBPointer.prototype.getCollection = function(){
         return this.ns;
-    }
+    };
 
     DBPointer.prototype.getId = function(){
         return this.id;
-    }
+    };
 
     DBPointer.prototype.toString = function(){
         return "DBPointer(" + tojson(this.ns) + ", " + tojson(this.id) + ")";
-    }
+    };
 }
 else {
     print("warning: no DBPointer");
@@ -382,28 +464,33 @@ if (typeof(DBRef) != "undefined"){
     DBRef.prototype.fetch = function(){
         assert(this.$ref, "need a ns");
         assert(this.$id, "need an id");
-        return db[ this.$ref ].findOne({ _id : this.$id });
-    }
+        var coll = this.$db ? db.getSiblingDB(this.$db).getCollection(this.$ref) : db[this.$ref];
+        return coll.findOne({ _id : this.$id });
+    };
 
     DBRef.prototype.tojson = function(indent){
         return this.toString();
-    }
+    };
+
+    DBRef.prototype.getDb = function(){
+        return this.$db || undefined;
+    };
 
     DBRef.prototype.getCollection = function(){
         return this.$ref;
-    }
+    };
 
     DBRef.prototype.getRef = function(){
         return this.$ref;
-    }
+    };
 
     DBRef.prototype.getId = function(){
         return this.$id;
-    }
+    };
 
     DBRef.prototype.toString = function(){
-        return "DBRef(" + tojson(this.$ref) + ", " + tojson(this.$id) + ")";
-    }
+        return "DBRef(" + tojson(this.$ref) + ", " + tojson(this.$id) + (this.$db ? ", " + tojson(this.$db) : "") + ")";
+    };
 }
 else {
     print("warning: no DBRef");
@@ -413,14 +500,14 @@ else {
 if (typeof(BinData) != "undefined"){
     BinData.prototype.tojson = function() {
         return this.toString();
-    }
+    };
 
     BinData.prototype.subtype = function() {
         return this.type;
-    }
+    };
     BinData.prototype.length = function() {
         return this.len;
-    }
+    };
 }
 else {
     print("warning: no BinData class");
@@ -430,7 +517,7 @@ else {
 if (typeof(Map) == "undefined"){
     Map = function(){
         this._data = {};
-    }
+    };
 }
 
 Map.hash = function(val){
@@ -451,19 +538,19 @@ Map.hash = function(val){
         return s;
     }
 
-    throw "can't hash : " + typeof(val);
-}
+    throw Error( "can't hash : " + typeof(val) );
+};
 
 Map.prototype.put = function(key, value){
     var o = this._get(key);
     var old = o.value;
     o.value = value;
     return old;
-}
+};
 
 Map.prototype.get = function(key){
     return this._get(key).value;
-}
+};
 
 Map.prototype._get = function(key){
     var h = Map.hash(key);
@@ -480,7 +567,7 @@ Map.prototype._get = function(key){
     var o = { key : key, value : null };
     a.push(o);
     return o;
-}
+};
 
 Map.prototype.values = function(){
     var all = [];
@@ -488,18 +575,18 @@ Map.prototype.values = function(){
         this._data[k].forEach(function(z){ all.push(z.value); });
     }
     return all;
-}
+};
 
 if (typeof(gc) == "undefined"){
     gc = function(){
         print("warning: using noop gc()");
-    }
+    };
 }
 
 // Free Functions
 tojsononeline = function(x){
     return tojson(x, " ", true);
-}
+};
 
 tojson = function(x, indent, nolint){
     if (x === null)
@@ -564,12 +651,14 @@ tojson = function(x, indent, nolint){
         return s;
     }
     case "function":
+        if (x === MinKey || x === MaxKey)
+            return x.tojson();
         return x.toString();
     default:
-        throw "tojson can't handle type " + (typeof x);
+        throw Error( "tojson can't handle type " + (typeof x) );
     }
 
-}
+};
 
 tojsonObject = function(x, indent, nolint){
     var lineEnding = nolint ? " " : "\n";
@@ -592,11 +681,7 @@ tojsonObject = function(x, indent, nolint){
     }
 
     try {
-        // modify display of min/max key for spidermonkey
-        if (x.toString() == "[object MaxKey]")
-            return "{ $maxKey : 1 }";
-        if (x.toString() == "[object MinKey]")
-            return "{ $minKey : 1 }";
+        x.toString();
     }
     catch(e) {
         // toString not callable
@@ -608,16 +693,10 @@ tojsonObject = function(x, indent, nolint){
     // push one level of indent
     indent += tabSpace;
 
-    var total = 0;
-    for (var k in x) total++;
-    if (total == 0) {
-        s += indent + lineEnding;
-    }
-
     var keys = x;
     if (typeof(x._simpleKeys) == "function")
         keys = x._simpleKeys();
-    var num = 1;
+    var fieldStrings = [];
     for (var k in keys){
         var val = x[k];
 
@@ -627,35 +706,39 @@ tojsonObject = function(x, indent, nolint){
         if (typeof DBCollection != 'undefined' && val == DBCollection.prototype)
             continue;
 
-        s += indent + "\"" + k + "\" : " + tojson(val, indent, nolint);
-        if (num != total) {
-            s += ",";
-            num++;
-        }
-        s += lineEnding;
+        fieldStrings.push(indent + "\"" + k + "\" : " + tojson(val, indent, nolint));
     }
 
+    if (fieldStrings.length > 0) {
+        s += fieldStrings.join("," + lineEnding);
+    }
+    else {
+        s += indent;
+    }
+    s += lineEnding;
+
     // pop one level of indent
     indent = indent.substring(1);
     return s + indent + "}";
-}
+};
 
 printjson = function(x){
     print( tojson( x ) );
-}
+};
 
 printjsononeline = function(x){
     print( tojsononeline( x ) );
-}
+};
 
 isString = function(x){
     return typeof(x) == "string";
-}
+};
 
 isNumber = function(x){
     return typeof(x) == "number";
-}
+};
 
+// This function returns true even if the argument is an array.  See SERVER-14220.
 isObject = function(x){
     return typeof(x) == "object";
-}
+};
