@@ -1,12 +1,12 @@
 __quiet = false;
-__magicNoPrint = { __magicNoPrint : 1111 }
+__magicNoPrint = { __magicNoPrint : 1111 };
 __callLastError = false; 
 _verboseShell = false;
 
 chatty = function(s){
     if ( ! __quiet )
         print( s );
-}
+};
 
 function reconnect(db) {
     assert.soon(function() {
@@ -17,7 +17,23 @@ function reconnect(db) {
                         return false;
                     }
                 });
-};
+}
+
+function _getErrorWithCode(codeOrObj, message) {
+    var e = new Error(message);
+    if (codeOrObj != undefined) {
+        if (codeOrObj.writeError) {
+            e.code = codeOrObj.writeError.code;
+        } else if (codeOrObj.code) {
+            e.code = codeOrObj.code;
+        } else {
+            // At this point assume codeOrObj is a number type
+            e.code = codeOrObj;
+        }
+    }
+
+    return e;
+}
 
 // Please consider using bsonWoCompare instead of this as much as possible.
 friendlyEqual = function( a , b ){
@@ -33,7 +49,7 @@ friendlyEqual = function( a , b ){
     var clean = function( s ){
         s = s.replace( /NumberInt\((\-?\d+)\)/g , "$1" );
         return s;
-    }
+    };
     
     a = clean(a);
     b = clean(b);
@@ -42,7 +58,7 @@ friendlyEqual = function( a , b ){
         return true;
     
     return false;
-}
+};
 
 printStackTrace = function(){
     try{
@@ -50,7 +66,7 @@ printStackTrace = function(){
     } catch (e) {
         print(e.stack);
     }
-}
+};
 
 /**
  * <p> Set the shell verbosity. If verbose the shell will display more information about command results. </>
@@ -60,14 +76,14 @@ printStackTrace = function(){
 setVerboseShell = function( value ) { 
     if( value == undefined ) value = true; 
     _verboseShell = value; 
-}
+};
 
 argumentsToArray = function( a ){
     var arr = [];
     for ( var i=0; i<a.length; i++ )
         arr[i] = a[i];
     return arr;
-}
+};
 
 // Formats a simple stacked horizontal histogram bar in the shell.
 // @param data array of the form [[ratio, symbol], ...] where ratio is between 0 and 1 and
@@ -90,16 +106,16 @@ _barFormat = function(data, width) {
     }
     res += "]";
     return res;
-}
+};
 
 
 //these two are helpers for Array.sort(func)
-compare = function(l, r){ return (l == r ? 0 : (l < r ? -1 : 1)); }
+compare = function(l, r){ return (l == r ? 0 : (l < r ? -1 : 1)); };
 
 // arr.sort(compareOn('name'))
 compareOn = function(field){
-    return function(l, r) { return compare(l[field], r[field]); }
-}
+    return function(l, r) { return compare(l[field], r[field]); };
+};
 
 
 shellPrint = function( x ){
@@ -117,26 +133,43 @@ shellPrint = function( x ){
         }
         db.resetError();
     }
-}
+};
+
+print.captureAllOutput = function (fn, args) {
+    var res = {};
+    res.output = [];
+    var __orig_print = print;
+    print = function () {
+        Array.prototype.push.apply(res.output, Array.prototype.slice.call(arguments).join(" ").split("\n"));
+    };
+    try {
+        res.result = fn.apply(undefined, args);
+    }
+    finally {
+        // Stop capturing print() output
+        print = __orig_print;
+    }
+    return res;
+};
 
 if ( typeof TestData == "undefined" ){
-    TestData = undefined
+    TestData = undefined;
 }
 
 jsTestName = function(){
-    if( TestData ) return TestData.testName
-    return "__unknown_name__"
-}
+    if( TestData ) return TestData.testName;
+    return "__unknown_name__";
+};
 
 jsTestFile = function(){
-    if( TestData ) return TestData.testFile
-    return "__unknown_file__"
-}
+    if( TestData ) return TestData.testFile;
+    return "__unknown_file__";
+};
 
 jsTestPath = function(){
-    if( TestData ) return TestData.testPath
-    return "__unknown_path__"
-}
+    if( TestData ) return TestData.testPath;
+    return "__unknown_path__";
+};
 
 var _jsTestOptions = { enableTestCommands : true }; // Test commands should be enabled by default
 
@@ -145,6 +178,10 @@ jsTestOptions = function(){
         return Object.merge(_jsTestOptions,
                             { setParameters : TestData.setParameters,
                               setParametersMongos : TestData.setParametersMongos,
+                              storageEngine: TestData.storageEngine,
+                              wiredTigerEngineConfigString: TestData.wiredTigerEngineConfigString,
+                              wiredTigerCollectionConfigString: TestData.wiredTigerCollectionConfigString,
+                              wiredTigerIndexConfigString: TestData.wiredTigerIndexConfigString,
                               noJournal : TestData.noJournal,
                               noJournalPrealloc : TestData.noJournalPrealloc,
                               auth : TestData.auth,
@@ -154,44 +191,55 @@ jsTestOptions = function(){
                               authMechanism : TestData.authMechanism,
                               adminUser : TestData.adminUser || "admin",
                               adminPassword : TestData.adminPassword || "password",
-                              useSSL : TestData.useSSL,
-                              useX509 : TestData.useX509});
+                              useLegacyConfigServers: TestData.useLegacyConfigServers || false,
+                              useLegacyReplicationProtocol:
+                                    TestData.useLegacyReplicationProtocol || false,
+                              enableMajorityReadConcern: TestData.enableMajorityReadConcern,
+                              enableEncryption: TestData.enableEncryption,
+                              encryptionKeyFile: TestData.encryptionKeyFile,
+                              auditDestination: TestData.auditDestination,
+                              minPort: TestData.minPort,
+                              maxPort: TestData.maxPort,
+                              // Note: does not support the array version
+                              mongosBinVersion: TestData.mongosBinVersion || "",
+                            }
+                        );
     }
     return _jsTestOptions;
-}
+};
 
 setJsTestOption = function(name, value) {
     _jsTestOptions[name] = value;
-}
+};
 
 jsTestLog = function(msg){
-    print( "\n\n----\n" + msg + "\n----\n\n" )
-}
+    print( "\n\n----\n" + msg + "\n----\n\n" );
+};
 
-jsTest = {}
+jsTest = {};
 
-jsTest.name = jsTestName
-jsTest.file = jsTestFile
-jsTest.path = jsTestPath
-jsTest.options = jsTestOptions
-jsTest.setOption = setJsTestOption
-jsTest.log = jsTestLog
-jsTest.readOnlyUserRoles = ["read"]
-jsTest.basicUserRoles = ["dbOwner"]
-jsTest.adminUserRoles = ["root"]
+jsTest.name = jsTestName;
+jsTest.file = jsTestFile;
+jsTest.path = jsTestPath;
+jsTest.options = jsTestOptions;
+jsTest.setOption = setJsTestOption;
+jsTest.log = jsTestLog;
+jsTest.readOnlyUserRoles = ["read"];
+jsTest.basicUserRoles = ["dbOwner"];
+jsTest.adminUserRoles = ["root"];
 
 jsTest.dir = function(){
-    return jsTest.path().replace( /\/[^\/]+$/, "/" )
-}
+    return jsTest.path().replace( /\/[^\/]+$/, "/" );
+};
 
 jsTest.randomize = function( seed ) {
-    if( seed == undefined ) seed = new Date().getTime()
-    Random.srand( seed )
-    print( "Random seed for test : " + seed ) 
-}
+    if( seed == undefined ) seed = new Date().getTime();
+    Random.srand( seed );
+    print( "Random seed for test : " + seed ); 
+};
 
 jsTest.authenticate = function(conn) {
-    if (!jsTest.options().auth && !jsTest.options().keyFile && !jsTest.options().useX509) {
+    if (!jsTest.options().auth && !jsTest.options().keyFile) {
         conn.authenticated = true;
         return true;
     }
@@ -215,7 +263,7 @@ jsTest.authenticate = function(conn) {
         conn.authenticated = false;
     }
     return conn.authenticated;
-}
+};
 
 jsTest.authenticateNodes = function(nodes) {
     assert.soon(function() {
@@ -231,14 +279,29 @@ jsTest.authenticateNodes = function(nodes) {
         }
         return true;
     }, "Authenticate to nodes: " + nodes, 30000);
-}
+};
 
 jsTest.isMongos = function(conn) {
     return conn.getDB('admin').isMaster().msg=='isdbgrid';
-}
+};
 
 defaultPrompt = function() {
     var status = db.getMongo().authStatus;
+    var prefix = db.getMongo().promptPrefix;
+
+    if (typeof prefix == 'undefined') {
+        prefix = "";
+        var buildInfo = db.runCommand({buildInfo: 1});
+        try {
+            if (buildInfo.modules.indexOf("enterprise") > -1) {
+                prefix = "MongoDB Enterprise ";
+            }
+        } catch (e) {
+            // Don't do anything here. Just throw the error away.
+        }
+        db.getMongo().promptPrefix = prefix;
+    }
+
     try {
         // try to use repl set prompt -- no status or auth detected yet
         if (!status || !status.authRequired) {
@@ -246,7 +309,7 @@ defaultPrompt = function() {
                 var prompt = replSetMemberStatePrompt();
                 // set our status that it was good
                 db.getMongo().authStatus = {replSetGetStatus:true, isMaster: true};
-                return prompt;
+                return prefix + prompt;
             } catch (e) {
                 // don't have permission to run that, or requires auth
                 //print(e);
@@ -262,7 +325,7 @@ defaultPrompt = function() {
                 // set our status that it was good
                 status.replSetGetStatus = true;
                 db.getMongo().authStatus = status;
-                return prompt;
+                return prefix + prompt;
             } catch (e) {
                 // don't have permission to run that, or requires auth
                 //print(e);
@@ -277,7 +340,7 @@ defaultPrompt = function() {
                 var prompt = isMasterStatePrompt();
                 status.isMaster = true;
                 db.getMongo().authStatus = status;
-                return prompt;
+                return prefix + prompt;
             } catch (e) {
                 status.authRequired = true;
                 status.isMaster = false;
@@ -290,8 +353,8 @@ defaultPrompt = function() {
     }
 
     db.getMongo().authStatus = status;
-    return "> ";
-}
+    return prefix + "> ";
+};
 
 replSetMemberStatePrompt = function() {
     var state = '';
@@ -313,11 +376,11 @@ replSetMemberStatePrompt = function() {
          if ( info && info.length < 20 ) {
              state = info; // "mongos", "configsvr"
          } else {
-             throw Error("Failed:" + info);
+             throw _getErrorWithCode(stateInfo, "Failed:" + info);
          }
     }
     return state + '> ';
-}
+};
 
 isMasterStatePrompt = function() {
     var state = '';
@@ -337,26 +400,31 @@ isMasterStatePrompt = function() {
             else if (isMaster.arbiterOnly)
                 role = "ARBITER";
             else {
-                role = "OTHER"
+                role = "OTHER";
             }
             state = isMaster.setName + ':';
         }
         state = state + role;
     } else {
-        throw Error("Failed: " + tojson(isMaster));
+        throw _getErrorWithCode(isMaster, "Failed: " + tojson(isMaster));
     }
     return state + '> ';
-}
+};
 
 if (typeof(_useWriteCommandsDefault) == 'undefined') {
     // This is for cases when the v8 engine is used other than the mongo shell, like map reduce.
     _useWriteCommandsDefault = function() { return false; };
-};
+}
 
 if (typeof(_writeMode) == 'undefined') {
     // This is for cases when the v8 engine is used other than the mongo shell, like map reduce.
     _writeMode = function() { return "commands"; };
-};
+}
+
+if (typeof(_readMode) == 'undefined') {
+    // This is for cases when the v8 engine is used other than the mongo shell, like map reduce.
+    _readMode = function() { return "legacy"; };
+}
 
 shellPrintHelper = function (x) {
     if (typeof (x) == "undefined") {
@@ -384,6 +452,9 @@ shellPrintHelper = function (x) {
         return;
     }
 
+    if (x === MinKey || x === MaxKey)
+        return x.tojson();
+
     if (typeof x != "object")
         return print(x);
 
@@ -396,7 +467,7 @@ shellPrintHelper = function (x) {
         print(x.tojson());
     else
         print(tojson(x));
-}
+};
 
 shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on init. Actual function at end
 
@@ -420,6 +491,9 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
     builtinMethods[BinData] = "hex base64 length subtype".split(' ');
 
     var extraGlobals = "Infinity NaN undefined null true false decodeURI decodeURIComponent encodeURI encodeURIComponent escape eval isFinite isNaN parseFloat parseInt unescape Array Boolean Date Math Number RegExp String print load gc MinKey MaxKey Mongo NumberInt NumberLong ObjectId DBPointer UUID BinData HexData MD5 Map Timestamp JSON".split( ' ' );
+    if (typeof NumberDecimal !== 'undefined') {
+        extraGlobals[extraGlobals.length] = "NumberDecimal";
+    }
 
     var isPrivate = function( name ) {
         if ( shellAutocomplete.showPrivate ) return false;
@@ -427,7 +501,7 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
         if ( name[0] == '_' ) return true;
         if ( name[name.length - 1] == '_' ) return true; // some native functions have an extra name_ method
         return false;
-    }
+    };
 
     var customComplete = function( obj ) {
         try {
@@ -445,7 +519,7 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
             // print( e ); // uncomment if debugging custom completers
             return [];
         }
-    }
+    };
 
     var worker = function( prefix ) {
         var global = ( function() { return this; } ).call(); // trick to get global object
@@ -459,7 +533,7 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
         }
 
         var lastPrefix = parts[parts.length - 1] || '';
-        var lastPrefixLowercase = lastPrefix.toLowerCase()
+        var lastPrefixLowercase = lastPrefix.toLowerCase();
         var beginning = parts.slice( 0, parts.length - 1 ).join( '.' );
         if ( beginning.length )
             beginning += '.';
@@ -495,7 +569,7 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
             ret.push( i );
 
         return ret;
-    }
+    };
 
     // this is the actual function that gets assigned to shellAutocomplete
     return function( prefix ) {
@@ -505,7 +579,7 @@ shellAutocomplete = function ( /*prefix*/ ) { // outer scope function called on
             print( "exception during autocomplete: " + tojson( e.message ) );
             __autocomplete__ = [];
         }
-    }
+    };
 } ();
 
 shellAutocomplete.showPrivate = false; // toggle to show (useful when working on internals)
@@ -515,14 +589,14 @@ shellHelper = function( command , rest , shouldPrint ){
     var args = rest.trim().replace(/\s*;$/,"").split( "\s+" );
     
     if ( ! shellHelper[command] )
-        throw "no command [" + command + "]";
+        throw Error( "no command [" + command + "]" );
     
     var res = shellHelper[command].apply( null , args );
     if ( shouldPrint ){
         shellPrintHelper( res );
     }
     return res;
-}
+};
 
 shellHelper.use = function (dbname) {
     var s = "" + dbname;
@@ -532,7 +606,7 @@ shellHelper.use = function (dbname) {
     }
     db = db.getMongo().getDB(dbname);
     print("switched to db " + db.getName());
-}
+};
 
 shellHelper.set = function (str) {
     if (str == "") {
@@ -552,7 +626,7 @@ shellHelper.set = function (str) {
         _verboseShell = value;
     }
     print("set " + param + " to " + value);
-}
+};
 
 shellHelper.it = function(){
     if ( typeof( ___it___ ) == "undefined" || ___it___ == null ){
@@ -560,14 +634,14 @@ shellHelper.it = function(){
         return;
     }
     shellPrintHelper( ___it___ );
-}
+};
 
 shellHelper.show = function (what) {
     assert(typeof what == "string");
 
     var args = what.split( /\s+/ );
-    what = args[0]
-    args = args.splice(1)
+    what = args[0];
+    args = args.splice(1);
 
     if (what == "profile") {
         if (db.system.profile.count() == 0) {
@@ -602,7 +676,7 @@ shellHelper.show = function (what) {
                     print( l );
                     print("\n"); 
                 }
-            )
+            );
         }
         return "";
     }
@@ -618,7 +692,7 @@ shellHelper.show = function (what) {
     }
 
     if (what == "collections" || what == "tables") {
-        db.getCollectionNames().forEach(function (x) { print(x) });
+        db.getCollectionNames().forEach(function (x) { print(x); });
         return "";
     }
 
@@ -645,7 +719,7 @@ shellHelper.show = function (what) {
             });
         });
 
-        dbinfo.sort(compareOn('name'))
+        dbinfo.sort(compareOn('name'));
         dbinfo.forEach(function (db) {
             var namePadding = maxNameLength - db.name_size;
             var sizePadding = maxGbDigits   - db.gb_digits;
@@ -663,7 +737,7 @@ shellHelper.show = function (what) {
     if (what == "log" ) {
         var n = "global";
         if ( args.length > 0 )
-            n = args[0]
+            n = args[0];
         
         var res = db.adminCommand( { getLog : n } );
         if ( ! res.ok ) {
@@ -671,21 +745,21 @@ shellHelper.show = function (what) {
             return "";
         }
         for ( var i=0; i<res.log.length; i++){
-            print( res.log[i] )
+            print( res.log[i] );
         }
-        return ""
+        return "";
     }
 
     if (what == "logs" ) {
-        var res = db.adminCommand( { getLog : "*" } )
+        var res = db.adminCommand( { getLog : "*" } );
         if ( ! res.ok ) {
             print("Error while trying to show logs: " + res.errmsg);
             return "";
         }
         for ( var i=0; i<res.names.length; i++){
-            print( res.names[i] )
+            print( res.names[i] );
         }
-        return ""
+        return "";
     }
 
     if (what == "startupWarnings" ) {
@@ -705,7 +779,7 @@ shellHelper.show = function (what) {
                 }
                 print( "Server has startup warnings: " );
                 for ( var i=0; i<res.log.length; i++){
-                    print( res.log[i] )
+                    print( res.log[i] );
                 }
                 return "";
             } else if (res.errmsg == "no such cmd: getLog" ) {
@@ -726,9 +800,9 @@ shellHelper.show = function (what) {
         }
     }
 
-    throw "don't know how to show [" + what + "]";
+    throw Error( "don't know how to show [" + what + "]" );
 
-}
+};
 
 Math.sigFig = function( x , N ){
     if ( ! N ){
@@ -736,24 +810,23 @@ Math.sigFig = function( x , N ){
     }
     var p = Math.pow( 10, N - Math.ceil( Math.log( Math.abs(x) ) / Math.log( 10 )) );
     return Math.round(x*p)/p;
-}
+};
 
-Random = function() {}
+Random = function() {};
 
 // set random seed
-Random.srand = function( s ) { _srand( s ); }
+Random.srand = function( s ) { return _srand( s ); };
 
 // random number 0 <= r < 1
-Random.rand = function() { return _rand(); }
+Random.rand = function() { return _rand(); };
 
 // random integer 0 <= r < n
-Random.randInt = function( n ) { return Math.floor( Random.rand() * n ); }
+Random.randInt = function( n ) { return Math.floor( Random.rand() * n ); };
 
 Random.setRandomSeed = function( s ) {
-    s = s || new Date().getTime();
-    print( "setting random seed: " + s );
-    Random.srand( s );
-}
+    var seed = Random.srand( s );
+    print("setting random seed: " + seed);
+};
 
 // generate a random value from the exponential distribution with the specified mean
 Random.genExp = function( mean ) {
@@ -765,7 +838,7 @@ Random.genExp = function( mean ) {
         }
     }
     return -Math.log( r ) * mean;
-}
+};
 
 /**
  * Generate a random value from the normal distribution with specified 'mean' and
@@ -784,7 +857,7 @@ Random.genNormal = function( mean, standardDeviation ) {
             return mean + ( standardDeviation * standardNormal );
         }
     }
-}
+};
 
 Geo = {};
 Geo.distance = function( a , b ){
@@ -809,7 +882,7 @@ Geo.distance = function( a , b ){
 
     return Math.sqrt( Math.pow( by - ay , 2 ) + 
                       Math.pow( bx - ax , 2 ) );
-}
+};
 
 Geo.sphereDistance = function( a , b ){
     var ax = null;
@@ -849,9 +922,9 @@ Geo.sphereDistance = function( a , b ){
     }
 
     return Math.acos(cross_prod);
-}
+};
 
-rs = function () { return "try rs.help()"; }
+rs = function () { return "try rs.help()"; };
 
 /**
  * This method is intended to aid in the writing of tests. It takes a host's address, desired state,
@@ -867,7 +940,7 @@ _awaitRSHostViaRSMonitor = function(hostAddr, desiredState, rsName, timeout) {
         desiredState = {ok: true};
     }
 
-    print("Awaiting " + hostAddr + " to be " + tojson(desiredState) + " in " + " rs " + rsName)
+    print("Awaiting " + hostAddr + " to be " + tojson(desiredState) + " in " + " rs " + rsName);
 
     var tests = 0;
     assert.soon(function() {
@@ -877,7 +950,7 @@ _awaitRSHostViaRSMonitor = function(hostAddr, desiredState, rsName, timeout) {
         }
 
         for (var i=0; i<stats.length; i++) {
-            var node = stats[i]
+            var node = stats[i];
             printjson(node);
             if (node["addr"] !== hostAddr)
                 continue;
@@ -886,7 +959,7 @@ _awaitRSHostViaRSMonitor = function(hostAddr, desiredState, rsName, timeout) {
             var stateReached = true;
             for(var prop in desiredState) {
                 if (isObject(desiredState[prop])) {
-                    if (!friendlyEqual(desiredState[prop], node[prop])) {
+                    if (!friendlyEqual(sortDoc(desiredState[prop]), sortDoc(node[prop]))) {
                         stateReached = false;
                         break;
                     }
@@ -905,37 +978,36 @@ _awaitRSHostViaRSMonitor = function(hostAddr, desiredState, rsName, timeout) {
     }, "timed out waiting for replica set member: " + hostAddr + " to reach state: " +
             tojson(desiredState),
     timeout);
-}
+};
 
 rs.help = function () {
-    print("\trs.status()                     { replSetGetStatus : 1 } checks repl set status");
-    print("\trs.initiate()                   { replSetInitiate : null } initiates set with default settings");
-    print("\trs.initiate(cfg)                { replSetInitiate : cfg } initiates set with configuration cfg");
-    print("\trs.conf()                       get the current configuration object from local.system.replset");
-    print("\trs.reconfig(cfg)                updates the configuration of a running replica set with cfg (disconnects)");
-    print("\trs.add(hostportstr)             add a new member to the set with default attributes (disconnects)");
-    print("\trs.add(membercfgobj)            add a new member to the set with extra attributes (disconnects)");
-    print("\trs.addArb(hostportstr)          add a new member which is arbiterOnly:true (disconnects)");
-    print("\trs.stepDown([secs])             step down as primary (momentarily) (disconnects)");
-    print("\trs.syncFrom(hostportstr)        make a secondary to sync from the given member");
-    print("\trs.freeze(secs)                 make a node ineligible to become primary for the time specified");
-    print("\trs.remove(hostportstr)          remove a host from the replica set (disconnects)");
-    print("\trs.slaveOk()                    shorthand for db.getMongo().setSlaveOk()");
+    print("\trs.status()                                { replSetGetStatus : 1 } checks repl set status");
+    print("\trs.initiate()                              { replSetInitiate : null } initiates set with default settings");
+    print("\trs.initiate(cfg)                           { replSetInitiate : cfg } initiates set with configuration cfg");
+    print("\trs.conf()                                  get the current configuration object from local.system.replset");
+    print("\trs.reconfig(cfg)                           updates the configuration of a running replica set with cfg (disconnects)");
+    print("\trs.add(hostportstr)                        add a new member to the set with default attributes (disconnects)");
+    print("\trs.add(membercfgobj)                       add a new member to the set with extra attributes (disconnects)");
+    print("\trs.addArb(hostportstr)                     add a new member which is arbiterOnly:true (disconnects)");
+    print("\trs.stepDown([stepdownSecs, catchUpSecs])   step down as primary (disconnects)");
+    print("\trs.syncFrom(hostportstr)                   make a secondary sync from the given member");
+    print("\trs.freeze(secs)                            make a node ineligible to become primary for the time specified");
+    print("\trs.remove(hostportstr)                     remove a host from the replica set (disconnects)");
+    print("\trs.slaveOk()                               allow queries on secondary nodes");
     print();
-    print("\trs.printReplicationInfo()       check oplog size and time range");
-    print("\trs.printSlaveReplicationInfo()  check replica set members and replication lag");
-    print("\tdb.isMaster()                   check who is primary");
+    print("\trs.printReplicationInfo()                  check oplog size and time range");
+    print("\trs.printSlaveReplicationInfo()             check replica set members and replication lag");
+    print("\tdb.isMaster()                              check who is primary");
     print();
     print("\treconfiguration helpers disconnect from the database so the shell will display");
     print("\tan error, even if the command succeeds.");
-    print("\tsee also http://<mongod_host>:28017/_replSet for additional diagnostic info");
-}
-rs.slaveOk = function (value) { return db.getMongo().setSlaveOk(value); }
-rs.status = function () { return db._adminCommand("replSetGetStatus"); }
-rs.isMaster = function () { return db.isMaster(); }
-rs.initiate = function (c) { return db._adminCommand({ replSetInitiate: c }); }
-rs.printSlaveReplicationInfo = function () { return db.printSlaveReplicationInfo() };
-rs.printReplicationInfo = function () { return db.printReplicationInfo() };
+};
+rs.slaveOk = function (value) { return db.getMongo().setSlaveOk(value); };
+rs.status = function () { return db._adminCommand("replSetGetStatus"); };
+rs.isMaster = function () { return db.isMaster(); };
+rs.initiate = function (c) { return db._adminCommand({ replSetInitiate: c }); };
+rs.printSlaveReplicationInfo = function () { return db.printSlaveReplicationInfo(); };
+rs.printReplicationInfo = function () { return db.printReplicationInfo(); };
 rs._runCmd = function (c) {
     // after the command, catch the disconnect and reconnect if necessary
     var res = null;
@@ -961,7 +1033,7 @@ rs._runCmd = function (c) {
         return "";
     }
     return res;
-}
+};
 rs.reconfig = function (cfg, options) {
     cfg.version = rs.conf().version + 1;
     cmd = { replSetReconfig: cfg };
@@ -969,7 +1041,7 @@ rs.reconfig = function (cfg, options) {
         cmd[i] = options[i];
     }
     return this._runCmd(cmd);
-}
+};
 rs.add = function (hostport, arb) {
     var cfg = hostport;
 
@@ -988,15 +1060,37 @@ rs.add = function (hostport, arb) {
         if (arb)
             cfg.arbiterOnly = true;
     }
+    else if (arb == true) {
+        throw Error("Expected first parameter to be a host-and-port string of arbiter, but got " +
+                    tojson(hostport));
+    }
+
+    if (cfg._id == null){
+        cfg._id = max+1;
+    }
     c.members.push(cfg);
     return this._runCmd({ replSetReconfig: c });
-}
+};
 rs.syncFrom = function (host) { return db._adminCommand({replSetSyncFrom : host}); };
-rs.stepDown = function (secs) { return db._adminCommand({ replSetStepDown:(secs === undefined) ? 60:secs}); }
-rs.freeze = function (secs) { return db._adminCommand({replSetFreeze:secs}); }
-rs.addArb = function (hn) { return this.add(hn, true); }
-rs.conf = function () { return db.getSisterDB("local").system.replset.findOne(); }
-rs.config = function () { return rs.conf(); }
+rs.stepDown = function (stepdownSecs, catchUpSecs) {
+    var cmdObj = {replSetStepDown: stepdownSecs === undefined ? 60 : stepdownSecs};
+    if (catchUpSecs !== undefined) {
+        cmdObj['secondaryCatchUpPeriodSecs'] = catchUpSecs;
+    }
+    return db._adminCommand(cmdObj);
+};
+rs.freeze = function (secs) { return db._adminCommand({replSetFreeze:secs}); };
+rs.addArb = function (hn) { return this.add(hn, true); };
+
+rs.conf = function () { 
+    var resp = db._adminCommand({replSetGetConfig:1});
+    if (resp.ok && !(resp.errmsg) && resp.config)
+        return resp.config;
+    else if (resp.errmsg && resp.errmsg.startsWith("no such cmd"))
+        return db.getSisterDB("local").system.replset.findOne(); 
+    throw new Error("Could not retrieve replica set config: " + tojson(resp));
+};
+rs.config = rs.conf;
 
 rs.remove = function (hn) {
     var local = db.getSisterDB("local");
@@ -1130,16 +1224,8 @@ help = shellHelper.help = function (x) {
         return;
     }
     else if (x == "test") {
-        print("\tstartMongodEmpty(args)        DELETES DATA DIR and then starts mongod");
+        print("\tMongoRunner.runMongod(args)   DELETES DATA DIR and then starts mongod");
         print("\t                              returns a connection to the new server");
-        print("\tstartMongodTest(port,dir,options)");
-        print("\t                              DELETES DATA DIR");
-        print("\t                              automatically picks port #s starting at 27000 and increasing");
-        print("\t                              or you can specify the port as the first arg");
-        print("\t                              dir is /data/db/<port>/ if not specified as the 2nd arg");
-        print("\t                              returns a connection to the new server");
-        print("\tresetDbpath(dirpathstr)       deletes everything under the dir specified including subdirs");
-        print("\tstopMongoProgram(port[, signal])");
         return;
     }
     else if (x == "") {
@@ -1168,4 +1254,4 @@ help = shellHelper.help = function (x) {
     }
     else
         print("unknown help option");
-}
+};
